#----------------------------------------------------------------------
# This file was generated by C:\Python25\Lib\site-packages\wx-2.8-msw-unicode\wx\tools\img2py.py
#
from wx import ImageFromStream, BitmapFromImage, EmptyIcon
import cStringIO, zlib


def getData():
    return zlib.decompress(
'x\xda\x01\xf5\x03\n\xfc\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00 \x00\
\x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\
\x08d\x88\x00\x00\x03\xacIDATX\x85\xe5\x97\xcfK+W\x14\xc7?\x93d\x921&5\xc4TD\
\x9fZ4\xb8x\xbc\x85F\xe9?P\xca\xdb\n\xee\xdd\xd5TT\xac\xbb\x16\xe9+B\x97>\
\xa5.Z(B\xb7.\xba.v\xe9>\x1b\x17\x82P\x8a\xf8\xe3\x11SS\x13\'\xc6\x9a\x99;s\
\xbbp2L\x12\x7f\xcc3\xb6]\xf4\x0b\x87\xdc{\xee\x99s\xbe|\xcf\xbdw&\xf0\x7f\
\x87r\xdf\xc2\xc6\xc6\xc6\x0f\x86a\xcc\x02\x816k\xd8\xe1p\xf8\xc7\xe5\xe5\
\xe5\xb9\xbb\x16C\xf7=e\x9a\xe6\xec\xd2\xd2R\xbb\xc5\x01\x02\x9b\x9b\x9b\xb3\
\xc0\xfb\x11\x90R\x06\x00\xce\xce\xce\xda\xaa\xde\xdb\xdb\xeb\xe6z/\x02^\x9c\
\x9c\x9c\xdc\xe9\x17BP*\x95H\xa5R(Jc7\x07\x06\x06|\x11|\x94\x80\xaa\xaa\x0c\
\x0f\x0f\xdfY|oo\x8fZ\xad\x86\x10\x82\xd1\xd1Q_\x05\x9fD\xe0\xf8\xf8\x18\x00\
)\xa5\xeb\xcf\xe7\xf3T\xabU\x00\n\x85\x02\x00\xf1x\xdc]\x1f\x1c\x1c|\x1e\x02\
\xa1P\xa8E\x81\x83\x83\x03\xb7x\x1d\xe7\xe7\xe7\xa4\xd3ib\xb1\x98\xeb\xf3\
\x12~2\x01UU9::r\xe7\xa5R\x89\xd3\xd3\xd3\x968\xdb\xb6\xc9\xe5r\x8c\x8c\x8c\
\x10\x08\x04\x18\x1a\x1az\xb4\xb8o\x02\xe9t\x1a\x80b\xb1\xc8\xfe\xfe\xfe\xbd\
\xb1\xb5Z\r]\xd7\x99\x9c\x9c\xf4U\xdc7\x81\xc3\xc3Cw\x9e\xc9d\x00\xc8\xe5r-\
\xb1SSS\xa8\xaa\xda\xe0\x13B\xb4G@\xd7uR\xa9\x94;o>n^\xdc\xdc\xdc \x84h\x88\
\t\x85\x1e.\xf1\xe0\xaaa\x18\xeeE\xe4M\xaa(\x8a\xab\x84\xd7_,\x16[\x88\xf6\
\xf4\xf4\xf8\'\x90\xcdf?\x0e\x06\x83\xbfX\x96\xd5\rpqqqgR/\x9a}\xcd\xf3\xba\
\x02\xd9lV\x86\x82\xc1B\xcd0>\xd9\xda\xdar7\x92\x1b\xbd\xb8\xb8\x18\t\x06\
\x83\xbf\xaf\xac\xac\xf4\'\x12\t\xd6\xd7\xd7\x19\x1b\x1b\xa3R\xa9\xb4$\xbe\
\xebx\xddG\xa4\xb3\xb3\x93\\.\xc7\xc2\xc2\x02\xe5r\x99\xb5\xb5\xb5\xdf\x92\
\xc9\xe4\xcb\xd5\xd5U\xd1\xac\xc0W333=\x89D\x02\x80d2\xe9^0\xed\xe0\xea\xea\
\x8ax<\xce\xf5\xf55\xb1X\x8c\xe9\xe9\xe9\x8f\xb6\xb7\xb7\xbf\x04\xbem\x08\
\x9c\x9f\x9f/Y\x96%m\xdb\xf6e\x96e=\xc9\x84\x10rn\xee\xf3\xabz]W\x01!DBJI>\
\xff\x0eUU9=}\x87\xa6i$\x93I\xa4\x94\xdc\xaa.AJl)\x01\x89\xb4Ar\xdb\x0ey;\
\xb9]\x93\xcd~\x89\xaeW0\x85\xc9\xf8\xf8\x04\xb6-;[\x08\x00X\x96\xc5\xe5\xe5\
%\x03/\x06\xb1,\x8b\xae\x0f\xe2D;\xa2\x9e\x88zr\x1a}@\xe3\xb6h\x8e\x93\x9c\
\x15\xfe\xe0\xe6\xafk\x8cZ\xad\xe1\xe9\x86\xf7\xb4eY\xec\xec\xfc\x8a\x10&/\
\xfa\xfb\xd14\x8dpX\xf5X\x98p$L\xa4\xc1"D"\x114\xcdk\x1aZ\x87F\x87c\x00\xbb\
\xbb\xbb\x00\x18\xa6\xd1@\xa0E\x81\xbe\xbe>\xbe~\xf3\r\xa6i6\x04\xd6\xf7\xf8\
\xe3\xaf\x97V\xa8\xaa\xca\xabW/o\t\x18\x0f\x10\xb0m\x8b\x89\x89\x0c\x99\xcc8\
RJl\xdbv\xfa\xef\x19\xdb6\xb6\xe3\x93\x8e\xcf\xf63v~\xcd&\x02--\xf8\xa7a4)\
\xfb\xef\x13\xf8\xaf\x15hnA}\x0fD\x02\x81\x80Q\xa9\xe8\xe1h4\xea\xe9\xbbs\
\xde\xbdc\xdb{\x0f8{\xc1\xcfX\xdaH\t\xba~\x89\xa2(\x16\x90\x04\xca!G\x85\xae\
j\xb5\xfa\xfd\xdb\xb7\x1b_\xf8\xf9\x8cj\x07\x8a\xa2P.\x97\x7fr\x08H\xc5Q\xa1\
\x1bH\xbd~\xfd\xe9|w\xf7\x87\x9fI)}}\xae?\x01V\xa9T\xfaygg\xe7;\xe0O\xa0P?\
\xde\x9a\xc3\xa8\x0b\x88:\xa4\x9e\xe3_\x91\x17\xa6\x93\xd3\x04\xae\x80s\xe0\
\xb2\xf9\x05\xaf\x02a \xf2\xcc\xc5\x01,\xc7L\xc0\xe0iw\xda\xf3\xe3o\xfe\xfdT\
R\xd6\x04\xb1Y\x00\x00\x00\x00IEND\xaeB`\x829\x9b\xe7\xcb' )

def getBitmap():
    return BitmapFromImage(getImage())

def getImage():
    stream = cStringIO.StringIO(getData())
    return ImageFromStream(stream)

def getIcon():
    icon = EmptyIcon()
    icon.CopyFromBitmap(getBitmap())
    return icon




#----------------------------------------------------------------------
# This file was generated by C:\Python25\Lib\site-packages\wx-2.8-msw-unicode\wx\tools\img2py.py
#
from wx import ImageFromStream, BitmapFromImage, EmptyIcon
import cStringIO, zlib


def getData():
    return zlib.decompress(
'x\xda\x01\x96\x05i\xfa\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00 \x00\
\x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\
\x08d\x88\x00\x00\x05MIDATX\x85\xed\x96Ol\x13\xd9\x1d\xc7?ofl\'v\xb6\x0eN\
\x1c\xa5E\x02\xad@P$\x96C\xb47\n\xe5\x92Ks\xe1\x88\xb6R9\xf5\xc4\xa9\xf7\x82\
\x84\xf6\x80\xe8\xb5\x87\xaa\x08\xf5\x86\xca\xa1Zi\x0fU\xa5\xa5\xda\xf6\xd0U\
\xcb\x8av\xd5\x06*6 \xc7I\x086\x8e\'x<\xf6\x8cg\xe6\xfd\xe9!\xb1\xeb\xb1M \
\xab\xaa\xbd\xf4;\x1a\xbd\xf7~\xbf7\xef\xfb\xfd\xfd\xde{\xf3\x1e\xfc\x8f!\
\x0er\xae\xac\xac\xfc\x00\xf8m&\x93\xe9\x8e\xf6\xb5,\x0b\xdb\xb6\xb1m[\xd8\
\xb6\x8d\xe38\xfd6\x96eaY\x96\rd\x87m\xc3\xe5\xad[\xb7\x04\x80s\xa0:!\xbe\
\x9c\x9e\x9e\xe6\xfe\xfd\xfb\x05)%\xc6\x18\x00\x8c1\x83\xb7\x8f\xd1\xb6eYd2\
\x99\xd4x}\xff\xf5\xeb\xd7\x076\x07\xe0\xea\xd5\xab\x7fL\x92\xe4\xfb\x93D\
\x84a8,(U\xbe\r\xc3\x82\xfaPJ\xa1\xb5V)\x01I\x92\x9c\xbfq\xe3\x06\xadV+\x15\
\x811\x86\xdb\xb7o\x03\xe0\xba.\x0f\x1e<x\'\xe2I8}\xfa4\xe7\xce\x9d\xc3\xf7}\
\x84\x10\x9d\x94\x00\xdb\xb6_W\xab\xd5\xf2\xf3\xe7\xcfS\x1f\x05A\xc0\xc9\x93\
\'\x91R\x02\xb0\xbc\xbc\x0cL\xce\xc4\xa4\xfa\xa8-\x08\x02\xea\xf5:\x96e\xd5G\
\x05\xb8\xc5b\xb1<77\x97\x12\xd0n\xb7YZZ"\x0cC\xda\xed6\x0f\x1f><t\xe4\x97.]\
J\t\xa9V\xab\xc4q\xfc\x97\x94\x00\xa0\xd6j\xb5\xbe\xeb\xban\xea\xe3\x8d\x8d\
\r\xae\\\xb9B\xab\xd5"\x8ec\x96\x96\x96\xde\x1a\xe5h}t\r\xad\xaf\xafw\xc30\
\xfcSJ\x80Rj;\x9b\xcdR.\x97\xd1Z\x03\x90$\t\x9e\xe7\xb1\xb8\xb8\xc8\xea\xea*\
/^\xbc\xa0\xd3\x19L\xdd\xa1q\xe6\xcc\x192\x99\x0c\x95JEi\xad\xd3\x02\xb4\xd6\
\xd5\x9d\x9d\x1d\xe3\xfb\xbe\x88\xa2\x08c\x0c[[[\xac\xac\xac\xd0h4\xe8v\xbb\
\x94J%J\xa5\xd2\xa1\xe7\xbd_&IB\xadV#\x8a\xa2\xe6\x9d;w\x9e\xa6\x04\x18c\xea\
\xbd^/Y\\\\\xcc\xfa\xbe\x0f\xc0\xa3G\x8f\xb8v\xed\x1akkkx\x9eG\xb7\xdb}\xe7h\
3\x99\x0c\xf3\xf3\xf3cBVWW\xc30\x0c\x7f1\xdcw \xc0u\xdd\xc4\xb2\xac\xac\xe7y\
\xb4\xdbmfgg\x91R\x0e\xb6f>\x9f?\xd4\xea\x0f\x82 eK\x92\x84g\xcf\x9e\xc5B\
\x88\xbbc\x02\x80W\xbe\xef\xeb\xb3g\xcfb\x8c\xa1R\xa9p\xf9\xf2e\xfe\xf9t\x8d\
\x9f}\x161\xfe;\xf9\x86\xc8.\x17\x81\xd7\x1f\xfexy\\@\xbb\xdd\x16\xae\xeb\
\xd2h4\xd8\xdc\xdc\xe4\xe8\xd1\xa3|\xfe\xe7U\x8e-\xce\xf0\x93\x8f\xce\x1f\
\x9e\xcc\xf4\x8bq\xf9\x06\x88"\xc9O\x7f\xf9\x87-\x07\xc0\xb2\xacW\x9e\xe7\
\xe5\x16\x16\x16\xd8\xde\xde\xe6\xd4\xa9St:\x1dZ!|\xa7<\x8b\xebG\xacnx\x07\
\xf1\xa4\x08\xc7m\xe9\xf6\xd1\xb9i^\xbf\xee\x80\xb1>\xb7\x00\xee\xdd\xbb\xd7\
\x8e\xa2\x08\xd7u\xa9T*\\\xb8p\x81f\xb3\xc9n (\x15\xf3\xb4\x03\x99"4\x801\
\xa0\xf7\x0f m\x0c\x1a\xb3\xdf\xde\xf3\x19\xdd\xef\xb3\xdf6{\xd2\x946d\x1d\
\x8b\xaf7\x9b]%\xe5\xef\xad\xfe\xc0B\x88V\xa1P I\x12fff\x10B\xd0\xe8\x18f\
\xbf\x95\xc7\x0f\xe5D\xc2\x14\xc1(a\xff\x19\x9c\x9c \x95!L$SY\x9b\xb5\x8d\
\xa6\xb0\x84\xf9bp\x1c[\x96\xb5\xdbl6\xcb\x9dN\x87L&\x83\xd6\x9a\xa6\xaf\x98\
\xc9gi\xf5\x12t\xff(\x9e\x98\xde\xfe1\xfd\xe6\xe9I\x94&\x91\x9a\xc2\x94\x83\
\xeb\x85D\xb1\x8c\xbf\xbc\xfb\xa3\xf5\xe1\x0c\xd4\x1c\xc7!\x08\x02\n\x85\x02\
\xb6\xed\xe0v$\xf9\xa9\x0ca\xac\'\xa6S\x0fE\xb7\x175\x83z\xdf\xa7\x94\xa1\
\x97(b\xa91@>g\xb3Q\xf3\x10\xb6\xf5\x05\x0c]H\xb4\xd6\xdb\xbb\xbb\xbb(\xa5\
\x10B\xb0\xd3\xd1\x94\x8f\x14\xe8%\x06\xa5\xf4X\x84\x93\x16\xdfp\x1f\xa5\xcd\
\xe0\x1dF\xd6\xb1Y\x7f\xe1vu\xac~\x93\x12\xa0\x94Z\x97R\x1a\xc7qD\x14El4c\
\x16\xe6\xde\xc3\x0f\x93At}B\xdd_\x07z\x7f\xae\x87\xa7c\x90\xa1q\x08\xb1w\
\xaf\xdb\xac\xb7l\xa9\xad\xcfF3\xf0\xaa\xd5jER\xca\xa9\x9b7o\xd2\x9e\xfb\x1e\
\x1f\x9e\xbfD\x10)\xa4\xdeK\xa52\x06\xa3\'\x0f\xfe.\xc896\xf5\xdd\x0e\xc6\
\x98\xdaW\xbf\xfa\xe8eJ\x00P\xeb\xf5z\xc9\xc5\x8b\x17\xa7vvvx\x18|\x9b\xfcT\
\x16/HH\xf6\xa7`\x14\x93\xae\\\x03\xdf\x04\x9b\xb0`\xf3\xe5\xae4\xda|\xd2\
\xb7\r\xef\x82\x86\xef\xfb*\x97\xcbQ\xf7\x14\xf6\xb4C\x8cE\x10\xff\xfb\x1f\
\x80\x99<\xf0\x81\xc4\xfb\x06\x01\xc4\x89a\xe3e\xb3\'5\xbf\x1e\x13 \xa5|\xe5\
\xfb\xbeS.\x97\xa9\x89\xf7\x99/\xcf\xe3\xf7$Z\x8dl\xbf7P\x9aqS\nB\x08Z\xcd6I\
\xac[\x7f\xbb\xfb\xc3\xbf\x8e\tx\xfc\xf8qx\xe2\xc4\x89\xdcW\xf5)B{\x8ecG\x8a\
\xf4b5>\xd2\x9bx&\x90\xa6\xfd\x86j\xb5\x16\x06\xbb[?\x07\xde\x03\xfc\x94\x80\
\'O\x9eD\xc7\x8f\x1f\x7f\xda0\xc7>@\x1a\x9e\xfc\xfd\xeb\x03\xc9\x0f\x03\x03\
\xca\x08\x81\x8a:\xffX\xfb\xf4\xe3\xdf\x01\xd9\xbeo\xf8\x82_\xcc\xe5r\xe5bi\
\xe1}\x91?R\x92I\x92\x1d\x1f\xea\xf0\xd0\xda\xc8^";Bi\x154+u\xa0\tl\x03jT\
\x00@\x0e(\x02\xd3@\x86\xff\x1c$\x90\x00\x1e\xd0\xe5\xedk\xf9\xff\xf8\xef\
\xe1_\x86IG\x92\xf3G\x04=\x00\x00\x00\x00IEND\xaeB`\x82\x8f\x9d\xc6\xf3' )

def getBitmap():
    return BitmapFromImage(getImage())

def getImage():
    stream = cStringIO.StringIO(getData())
    return ImageFromStream(stream)

def getIcon():
    icon = EmptyIcon()
    icon.CopyFromBitmap(getBitmap())
    return icon




"""
 File:  
 JetFile.py
 
 Contents and purpose:
 Auditions a jet file to simulate interactive music functions
 
 Copyright (c) 2008 Android Open Source Project
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
 
      http://www.apache.org/licenses/LICENSE-2.0
 
 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
"""

from __future__ import with_statement

import logging
import ConfigParser
import struct
import os
import sys
import midifile

from JetUtils import *
from JetDefs import *

VERSION = '0.1'

# JET file defines
JET_HEADER_STRUCT = '<4sl'
JET_HEADER_TAG = 'JET '
JET_VERSION = 0x01000000

# JET chunk tags
JET_INFO_CHUNK = 'JINF'
JET_SMF_CHUNK = 'JSMF'
JET_DLS_CHUNK = 'JDLS'

# JINF defines
JINF_STRUCT = '<4sl4sl4sl4sl'
JINF_JET_VERSION = 'JVER'
JINF_NUM_SMF_CHUNKS = 'SMF#'
JINF_NUM_DLS_CHUNKS = 'DLS#'

# JCOP defines
JCOP_STRUCT = '<4sl'
JCOP_CHUNK = 'JCOP'

# JAPP defines
JAPP_STRUCT = '<4sl'
JAPP_CHUNK = 'JAPP'

# config file defines
OUTPUT_SECTION = 'output'
OUTPUT_FILENAME = 'filename'
OUTPUT_COPYRIGHT = 'copyright'
OUTPUT_APP_DATA = 'app_data'
OUTPUT_CHASE_CONTROLLERS = 'chase_controllers'
OUTPUT_OMIT_EMPTY_TRACKS = 'omit_empty_tracks'
SEGMENT_SECTION = 'segment'
SEGMENT_FILENAME = 'filename'
SEGMENT_DLSFILE = 'dlsfile'
SEGMENT_NAME = 'segname'
SEGMENT_START = 'start'
SEGMENT_END = 'end'
SEGMENT_END_MARKER = 'end_marker'
SEGMENT_QUANTIZE = 'quantize'
SEGMENT_OUTPUT = 'output'
SEGMENT_LENGTH = 'length'
SEGMENT_DUMP_FILE = 'dump'
SEGMENT_TRANSPOSE = 'transpose'
SEGMENT_REPEAT = 'repeat'
SEGMENT_MUTE_FLAGS = 'mute_flags'
LIBRARY_SECTION = 'libraries'
LIBRARY_FILENAME = 'lib'
CLIP_PREFIX = 'clip'
APP_PREFIX = 'app'

# JET events
JET_EVENT_MARKER = 102
JET_MARKER_LOOP_END = 0
JET_EVENT_TRIGGER_CLIP = 103

class JetSegment (object):
    """ Class to hold segments """
    def __init__ (self, segname, filename, start=None, end=None, length=None, output=None, quantize=None, jetevents=[], dlsfile=None, dump_file=None, transpose=0, repeat=0, mute_flags=0):
        self.segname = segname
        self.filename = filename
        self.dlsfile = dlsfile
        self.start = start
        self.end = end
        self.length = length
        self.output = output
        self.quantize = quantize
        self.dump_file = dump_file
        self.jetevents = jetevents
        #API FIELDS FOR UI
        self.transpose = transpose
        self.repeat = repeat
        self.mute_flags = mute_flags        

class JetEvent (object):
    """ Class to hold events """
    def __init__(self, event_name, event_type, event_id, track_num, channel_num, event_start, event_end):
        self.event_name = event_name
        self.event_type = event_type
        self.event_id = event_id
        self.track_num = track_num
        self.channel_num = channel_num
        self.event_start = event_start
        self.event_end = event_end
  
class JetFileException (Exception):
    """ Exceptions class """
    def __init__ (self, msg):
        self.msg = msg
    def __str__ (self):
        return self.msg

class JetSegmentFile (midifile.MIDIFile):
    def ConvertMusicTimeToTicks (self, s):
        measures, beats, ticks = s.split(':',3)
        return self.ConvertToTicks(int(measures), int(beats), int(ticks))

    def ExtractEvents (self, start, end, length, quantize, chase_controllers):
        if (start is None) and (end is None) and (length is None):
            logging.debug('ExtractEvents: No change')
            return

        if start is not None:
            start = self.ConvertMusicTimeToTicks(start)
        else:
            start = 0
        if end is not None:
            end = self.ConvertMusicTimeToTicks(end)
        elif length is not None:
            length = self.ConvertMusicTimeToTicks(length)
            end = start + length

        if quantize is not None:
            quantize = int(quantize)
        else:
            quantize = 0

        self.Trim(start, end, quantize, chase_controllers=chase_controllers)
        #self.DumpTracks()

    def SyncClips (self):
        """Add controller events to the start of a clip to keep it synced."""
        values = None
        last_seq = 0
        for track in self.tracks:
            for event in track.events:

                # find start of clip and chase events from last save point
                if (event.msg_type == midifile.CONTROL_CHANGE) and \
                        (event.controller == JET_EVENT_TRIGGER_CLIP) and \
                        ((event.value & 0x40) == 0x40):
                    logging.debug('Syncing clip at %d ticks' % event.ticks)
                    values = track.events.ChaseControllers(event.seq, last_seq, values)
                    
                    #BTH; Seems to fix chase controller bug when multiple clips within segment
                    #last_seq = event.seq

                    # generate event list from default values
                    clip_events = values.GenerateEventList(event.ticks)
                    
                    #for evt in clip_events:
                    #    logging.info(evt)
                        
                    track.events.InsertEvents(clip_events, event.seq + 1)

    def AddJetEvents (self, jetevents):
        for jet_event in jetevents:
            if jet_event.event_type == JetDefs.E_CLIP:
                #DumpEvent(jet_event)
                
                # sanity check
                if jet_event.track_num >= len(self.tracks):
                    raise JetFileException('Track number %d of out of range for clip' % jet_event.track_num)
                if jet_event.channel_num > 15:
                    raise JetFileException('Channel number %d of out of range for clip' % jet_event.channel_num)
                if jet_event.event_id > 63:
                    raise JetFileException('event_id %d of out of range for clip' % jet_event.event_id)
    
                logging.debug('Adding trigger event for clip %d @ %s and %s' % (jet_event.event_id, jet_event.event_start, jet_event.event_end))
    
                events = midifile.EventList()
                events.append(midifile.ControlChangeEvent(
                    self.ConvertMusicTimeToTicks(jet_event.event_start),
                    0,
                    jet_event.channel_num,
                    JET_EVENT_TRIGGER_CLIP,
                    jet_event.event_id | 0x40))
    
                events.append(midifile.ControlChangeEvent(
                    self.ConvertMusicTimeToTicks(jet_event.event_end),
                    sys.maxint,
                    jet_event.channel_num,
                    JET_EVENT_TRIGGER_CLIP,
                    jet_event.event_id))
    
                # merge trigger events
                self.tracks[jet_event.track_num].events.MergeEvents(events)
                
            elif jet_event.event_type == JetDefs.E_EOS:
                if jet_event.track_num >= len(self.tracks):
                    raise JetFileException('Track number %d of out of range for end marker' % jet_event.track_num)
                if jet_event.channel_num > 15:
                    raise JetFileException('Channel number %d of out of range for end marker' % jet_event.channel_num)
    
                events = midifile.EventList()
                logging.debug('Adding end marker at %s' % jet_event.event_start)
                events.append(midifile.ControlChangeEvent(
                    self.ConvertMusicTimeToTicks(jet_event.event_start),
                    0,
                    jet_event.channel_num,
                    JET_EVENT_MARKER,
                    JET_MARKER_LOOP_END))
                self.tracks[jet_event.track_num].events.MergeEvents(events)

            elif jet_event.event_type == JetDefs.E_APP:
                if jet_event.track_num >= len(self.tracks):
                    raise JetFileException('Track number %d of out of range for app marker' % jet_event.track_num)
                if jet_event.channel_num > 15:
                    raise JetFileException('Channel number %d of out of range for app marker' % jet_event.channel_num)
                if jet_event.event_id > 83 or jet_event.event_id < 80:
                    raise JetFileException('EventID %d out of range for application controller' % jet_event.event_id)
    
                events = midifile.EventList()
                logging.debug('Adding application controller at %s' % jet_event.event_start)
                events.append(midifile.ControlChangeEvent(
                    self.ConvertMusicTimeToTicks(jet_event.event_start),
                    0,
                    jet_event.channel_num,
                    jet_event.event_id,
                    jet_event.event_id))
                self.tracks[jet_event.track_num].events.MergeEvents(events)

class JetFile (object):
    """Write a JET file based on a configuration file."""
    def __init__ (self, config_file, options):
        self.config_file = config_file
        self.config = config = ConfigParser.ConfigParser()
        if self.config_file == "":
            self.InitializeConfig(JetDefs.UNTITLED_FILE)
        if not FileExists(self.config_file):
            self.InitializeConfig(self.config_file)
        
        config.read(self.config_file)
        self.ParseConfig(options)

    def DumpConfig (self):
        """Drump configuration to log file."""
        # dump configuration
        config = self.config
        for section in config.sections():
            logging.debug('[%s]' % section)
            for option, value in config.items(section):
                logging.debug('%s: %s' % (option, value))

    def ParseConfig (self, options):
        """Validate the configuration."""
        # check for output name
        config = self.config
        if config.has_option(OUTPUT_SECTION, OUTPUT_FILENAME):
            config.filename = config.get(OUTPUT_SECTION, OUTPUT_FILENAME)
        else:
            raise JetFileException('No output filename in configuration file')
        if config.filename == '' or config.filename == None:
            config.filename = FileJustRoot(self.config_file) + ".JET"
        config.chase_controllers = True
        if config.has_option(OUTPUT_SECTION, OUTPUT_CHASE_CONTROLLERS):
            try:
                config.chase_controllers = config.getboolean(OUTPUT_SECTION, OUTPUT_CHASE_CONTROLLERS)
            except:
                pass

        config.delete_empty_tracks = False
        if config.has_option(OUTPUT_SECTION, OUTPUT_OMIT_EMPTY_TRACKS):
            try:
                config.delete_empty_tracks = config.getboolean(OUTPUT_SECTION, OUTPUT_OMIT_EMPTY_TRACKS)
            except:
                pass
                
        config.copyright = None
        if config.has_option(OUTPUT_SECTION, OUTPUT_COPYRIGHT):
            config.copyright = config.get(OUTPUT_SECTION, OUTPUT_COPYRIGHT)

        config.app_data = None
        if config.has_option(OUTPUT_SECTION, OUTPUT_APP_DATA):
            config.app_data = config.get(OUTPUT_SECTION, OUTPUT_APP_DATA)

        # count segments
        segments = []
        seg_num = 0
        while 1:

            # check for segment section
            segment_name = SEGMENT_SECTION + str(seg_num)
            if not config.has_section(segment_name):
                break

            # initialize some parameters
            start = end = length = output = end_marker = dlsfile = dump_file = None
            transpose = repeat = mute_flags = 0
            jetevents = []

            # get the segment parameters
            segname = config.get(segment_name, SEGMENT_NAME)
            filename = config.get(segment_name, SEGMENT_FILENAME)
            if config.has_option(segment_name, SEGMENT_DLSFILE):
                dlsfile = config.get(segment_name, SEGMENT_DLSFILE)
            if config.has_option(segment_name, SEGMENT_START):
                start = config.get(segment_name, SEGMENT_START)
            if config.has_option(segment_name, SEGMENT_END):
                end = config.get(segment_name, SEGMENT_END)
            if config.has_option(segment_name, SEGMENT_LENGTH):
                length = config.get(segment_name, SEGMENT_LENGTH)
            if config.has_option(segment_name, SEGMENT_OUTPUT):
                output = config.get(segment_name, SEGMENT_OUTPUT)
            if config.has_option(segment_name, SEGMENT_QUANTIZE):
                quantize = config.get(segment_name, SEGMENT_QUANTIZE)
            if config.has_option(segment_name, SEGMENT_DUMP_FILE):
                dump_file = config.get(segment_name, SEGMENT_DUMP_FILE)
            #API FIELDS
            if config.has_option(segment_name, SEGMENT_TRANSPOSE):
                transpose = config.get(segment_name, SEGMENT_TRANSPOSE)
            if config.has_option(segment_name, SEGMENT_REPEAT):
                repeat = config.get(segment_name, SEGMENT_REPEAT)
            if config.has_option(segment_name, SEGMENT_MUTE_FLAGS):
                mute_flags = config.get(segment_name, SEGMENT_MUTE_FLAGS)
            
            if config.has_option(segment_name, SEGMENT_END_MARKER):
                end_marker = config.get(segment_name, SEGMENT_END_MARKER)
                track_num, channel_num, event_time = end_marker.split(',',2)
                #jetevents.append((JetDefs.E_EOS, 0, int(track_num), int(channel_num), event_time, ''))
                jetevents.append(JetEvent(JetDefs.E_EOS, JetDefs.E_EOS, 0, int(track_num), int(channel_num), event_time, event_time))

            # check for jetevents
            for jetevent, location in config.items(segment_name):
                if jetevent.startswith(CLIP_PREFIX):
                    event_name, event_id, track_num, channel_num, event_start, event_end = location.split(',', 5)
                    jetevents.append(JetEvent(event_name, JetDefs.E_CLIP, int(event_id), int(track_num), int(channel_num), event_start, event_end))

            # check for appevents
            for jetevent, location in config.items(segment_name):
                if jetevent.startswith(APP_PREFIX):
                    event_name, event_id, track_num, channel_num, event_start, event_end = location.split(',', 5)
                    jetevents.append(JetEvent(event_name, JetDefs.E_APP, int(event_id), int(track_num), int(channel_num), event_start, event_end))
            
            segments.append(JetSegment(segname, filename, start, end, length, output, quantize, jetevents, dlsfile, dump_file, int(transpose), int(repeat), int(mute_flags)))
            seg_num += 1

        self.segments = segments
        if not len(segments):
            #TODO: Check for segments when writing
            #raise JetFileException('No segments defined in configuration file')
            pass

        # count libraries
        libraries = []
        lib_num = 0
        while 1:
            library_name = LIBRARY_FILENAME + str(lib_num)
            if not config.has_option(LIBRARY_SECTION, library_name):
                break
            libraries.append(config.get(LIBRARY_SECTION, library_name))
            lib_num += 1
        self.libraries = libraries

    def WriteJetFileFromConfig (self, options):
        """Write JET file from config file."""
        
        # open the output file and write the header
        output_file = open(self.config.filename, 'wb')
        jet_header = struct.pack(JET_HEADER_STRUCT, JET_HEADER_TAG, 0)
        output_file.write(jet_header)

        # write the JINF chunk
        jet_info = struct.pack(JINF_STRUCT,
            JET_INFO_CHUNK, struct.calcsize(JINF_STRUCT) - 8,
            JINF_JET_VERSION, JET_VERSION,
            JINF_NUM_SMF_CHUNKS, len(self.segments),
            JINF_NUM_DLS_CHUNKS, len(self.libraries))
        output_file.write(jet_info)

        # write the JCOP chunk (if any)
        if self.config.copyright is not None:
            size = len(self.config.copyright) + 1
            if size & 1:
                size += 1
                extra_byte = True
            else:
                extra_byte = False
            jet_copyright = struct.pack(JCOP_STRUCT, JCOP_CHUNK, size)
            output_file.write(jet_copyright)
            output_file.write(self.config.copyright)
            output_file.write(chr(0))
            if extra_byte:
                output_file.write(chr(0))

        # write the app data chunk (if any)
        if self.config.app_data is not None:
            size = os.path.getsize(self.config.app_data)
            if size & 1:
                size += 1
                extra_byte = True
            else:
                extra_byte = False
            jet_app_data = struct.pack(JAPP_STRUCT, JAPP_CHUNK, size)
            output_file.write(jet_app_data)
            with open(self.config.app_data, 'rb') as f:
                output_file.write(f.read())
            if extra_byte:
                output_file.write(chr(0))

        # copy the MIDI segments
        seg_num = 0
        for segment in self.segments:
            logging.debug('Writing segment %d' % seg_num)

            # open SMF file and read it
            jet_segfile = JetSegmentFile(segment.filename, 'rb')
            jet_segfile.ReadFromStream()

            # insert events
            jet_segfile.AddJetEvents(segment.jetevents)

            # trim to length specified in config file
            jet_segfile.ExtractEvents(segment.start, segment.end, segment.length, segment.quantize, self.config.chase_controllers)

            # chase controller events and fix them
            if self.config.chase_controllers:
                jet_segfile.SyncClips()

            # delete empty tracks
            if self.config.delete_empty_tracks:
                jet_segfile.DeleteEmptyTracks()

            # write separate output file if requested
            if segment.output is not None:
                jet_segfile.SaveAs(segment.output)

            # write dump file
            if segment.dump_file is not None:
                with open(segment.dump_file, 'w') as f:
                    jet_segfile.DumpTracks(f)

            # write the segment header
            header_pos = output_file.tell()
            smf_header = struct.pack(JET_HEADER_STRUCT, JET_SMF_CHUNK, 0)
            output_file.write(smf_header)
            start_pos = output_file.tell()

            # write SMF file to output file
            jet_segfile.Write(output_file, offset=start_pos)
            jet_segfile.close()

            # return to segment header and write actual size
            end_pos = output_file.tell()
            file_size = end_pos - start_pos
            if file_size & 1:
                file_size += 1
                end_pos += 1
            output_file.seek(header_pos, 0)
            smf_header = struct.pack(JET_HEADER_STRUCT, JET_SMF_CHUNK, file_size)
            output_file.write(smf_header)
            output_file.seek(end_pos, 0)

            seg_num += 1

        # copy the DLS segments
        for library in self.libraries:
            if FileExists(library):
                # open SMF file and get size
                lib_file = (open(library,'rb'))
                lib_file.seek(0,2)
                file_size = lib_file.tell()
                lib_file.seek(0)
    
                # write the library header
                dls_header = struct.pack(JET_HEADER_STRUCT, JET_DLS_CHUNK, file_size)
                output_file.write(dls_header)
    
                # copy DLS file to output file
                output_file.write(lib_file.read())
                lib_file.close()

        # write the header with the read data size
        file_size = output_file.tell()
        output_file.seek(0)
        jet_header = struct.pack(JET_HEADER_STRUCT, JET_HEADER_TAG, file_size - struct.calcsize(JET_HEADER_STRUCT))
        output_file.write(jet_header)
        output_file.close()
        
    def GetMidiFiles(self):
        """ Gets a list of midifiles """
        midiFiles = []
        for segment in self.segments:
            if segment.filename not in midiFiles:
                 midiFiles.append(segment.filename) 
        return midiFiles
            
    def GetLibraries(self):
        """ Gets the libraries """
        return self.libraries
    
    def GetEvents(self, segName):
        """ Gets the events for a segment """
        for segment in self.segments:
            if segment.segname == segName:
                return segment.jetevents
        return None
    
    def GetEvent(self, segName, eventName):
        """ Gets a single event from a segment """
        for segment in self.segments:
            if segment.segname == segName:
                for event in segment.jetevents:
                    if event.event_name == eventName:
                        return event
        return None
        
    def AddEvent(self, segname, event_name, event_type, event_id, track_num, channel_num, event_start, event_end):    
        """ Adds an event """
        for segment in self.segments:
            if segment.segname == segname:
                segment.jetevents.append(JetEvent(event_name, event_type, int(event_id), int(track_num), int(channel_num), event_start, event_end))
    
    def ReplaceEvents(self, segname, newEvents):
        """ Replaces all events """
        for segment in self.segments:
            if segment.segname == segname:
                segment.jetevents = newEvents
                return segment       
        
    def UpdateEvent(self, segname, orgeventname, event_name, event_type, event_id, track_num, channel_num, event_start, event_end):
        """ Updates an event """    
        for segment in self.segments:
            if segment.segname == segname:
                for jetevent in segment.jetevents:
                    if jetevent.event_name == orgeventname:
                        jetevent.event_name = event_name
                        jetevent.event_type = event_type
                        jetevent.event_id = event_id
                        jetevent.track_num = track_num
                        jetevent.channel_num = channel_num
                        jetevent.event_start = event_start
                        jetevent.event_end = event_end
                       
    def DeleteSegmentsMatchingPrefix(self, prefix):
        """ Deletes all segments matching name """
        iOnce = True
        iAgain = False
        while(iOnce or iAgain):
            iOnce = False
            iAgain = False
            for segment in self.segments:
                if segment.segname[0:len(prefix)].upper() == prefix.upper():
                    self.segments.remove(segment)
                    iAgain = True
                            
    def DeleteEvent(self, segname, event_name):
        """ Deletes an event """
        for segment in self.segments:
            if segment.segname == segname:
                for jetevent in segment.jetevents:
                    if jetevent.event_name == event_name:
                        segment.jetevents.remove(jetevent)

    def DeleteEventsMatchingPrefix(self, segname, prefix):
        """ Deletes all events matching name """
        for segment in self.segments:
            if segment.segname == segname:
                iOnce = True
                iAgain = False
                while(iOnce or iAgain):
                    iOnce = False
                    iAgain = False
                    for jetevent in segment.jetevents:
                        if jetevent.event_name[0:len(prefix)].upper() == prefix.upper():
                            segment.jetevents.remove(jetevent)
                            iAgain = True

    def MoveEvent(self, segname, movename, event_start, event_end):
        """ Move an event """    
        for segment in self.segments:
            if segment.segname == segname:
                for jetevent in segment.jetevents:
                    if jetevent.event_name == movename:
                        jetevent.event_start = event_start
                        jetevent.event_end = event_end
                        return
            
    def GetSegments(self):
        """ Gets all segments """
        return self.segments
   
    def GetSegment(self, segName):
        """ Gets one segment by name """
        for segment in self.segments:
            if segment.segname == segName:
                return segment
        return None
        
    def AddSegment(self, segname, filename, start, end, length, output, quantize, jetevents, dlsfile, dump_file, transpose, repeat, mute_flags):
        """ Adds a segment """
        if length == JetDefs.MBT_ZEROSTR:
            length = None
        if end == JetDefs.MBT_ZEROSTR:
            end = None
        self.segments.append(JetSegment(segname, filename, start, end, length, output, quantize, jetevents, dlsfile, dump_file, transpose, repeat, mute_flags))
    
    def UpdateSegment(self, orgsegname, segname, filename, start, end, length, output, quantize, jetevents, dlsfile, dump_file, transpose, repeat, mute_flags):
        """ Updates a segment """
        if length == JetDefs.MBT_ZEROSTR:
            length = None
        if end == JetDefs.MBT_ZEROSTR:
            end = None
        for segment in self.segments:
            if segment.segname == orgsegname:
                segment.segname = segname
                segment.filename = filename
                segment.start = start
                segment.end = end
                segment.length = length
                segment.output = output
                segment.quantize = quantize
                segment.dlsfile = dlsfile
                segment.transpose = transpose
                segment.repeat = repeat
                segment.mute_flags = mute_flags

    def MoveSegment(self, segname, start, end):
        """ Moves a segment """
        for segment in self.segments:
            if segment.segname == segname:
                segment.start = start
                segment.end = end
                return

    def DeleteSegment(self, segname):
        """ Deletes a segment """
        for segment in self.segments:
            if segment.segname == segname:
                self.segments.remove(segment)

    def SaveJetConfig(self, configFile):
        """ Saves the jet config file """
        if self.config.filename == '' or self.config.filename == None:
            self.config.filename = FileJustRoot(configFile) + ".JET"
        config = ConfigParser.ConfigParser()
        config.add_section(OUTPUT_SECTION)
        config.set(OUTPUT_SECTION, OUTPUT_FILENAME, self.config.filename)
        config.set(OUTPUT_SECTION, OUTPUT_CHASE_CONTROLLERS, self.config.chase_controllers)
        config.set(OUTPUT_SECTION, OUTPUT_OMIT_EMPTY_TRACKS, self.config.delete_empty_tracks)
        if self.config.copyright is not None:
            config.set(OUTPUT_SECTION, OUTPUT_COPYRIGHT, self.config.copyright)
        if self.config.app_data is not None:
            config.set(OUTPUT_SECTION, OUTPUT_APP_DATA, self.config.app_data)

        self.libraries = []
        seg_num = 0
        for segment in self.segments:
            segment_name = SEGMENT_SECTION + str(seg_num)
            config.add_section(segment_name)
            config.set(segment_name, SEGMENT_NAME, segment.segname)
            config.set(segment_name, SEGMENT_FILENAME, segment.filename)
            
            config.set(segment_name, SEGMENT_DLSFILE, segment.dlsfile)
            if FileExists(segment.dlsfile):
                if not segment.dlsfile in self.libraries:
                    self.libraries.append(segment.dlsfile)
            config.set(segment_name, SEGMENT_START, segment.start)
            if segment.end > JetDefs.MBT_ZEROSTR and len(segment.end) > 0:
                config.set(segment_name, SEGMENT_END, segment.end)
            if segment.length > JetDefs.MBT_ZEROSTR and len(segment.length) > 0:
                config.set(segment_name, SEGMENT_LENGTH, segment.length)
            config.set(segment_name, SEGMENT_OUTPUT, segment.output)
            config.set(segment_name, SEGMENT_QUANTIZE, segment.quantize)
            if segment.dump_file is not None:
                config.set(segment_name, SEGMENT_DUMP_FILE, segment.dump_file)
            config.set(segment_name, SEGMENT_TRANSPOSE, segment.transpose)
            config.set(segment_name, SEGMENT_REPEAT, segment.repeat)
            config.set(segment_name, SEGMENT_MUTE_FLAGS, segment.mute_flags)

            clip_num = 0
            app_num = 0
            for jet_event in segment.jetevents:
                if jet_event.event_type == JetDefs.E_CLIP:
                    clip_name = CLIP_PREFIX + str(clip_num)
                    s = "%s,%s,%s,%s,%s,%s" % (jet_event.event_name, jet_event.event_id, jet_event.track_num, jet_event.channel_num, jet_event.event_start, jet_event.event_end)
                    config.set(segment_name, clip_name, s)
                    clip_num += 1
                elif jet_event.event_type == JetDefs.E_APP:
                    app_name = APP_PREFIX + str(app_num)
                    s = "%s,%s,%s,%s,%s,%s" % (jet_event.event_name, jet_event.event_id, jet_event.track_num, jet_event.channel_num, jet_event.event_start, jet_event.event_end)
                    config.set(segment_name, app_name, s)
                    app_num += 1
                elif jet_event.event_type == JetDefs.E_EOS:
                    s = "%s,%s,%s" % (jet_event.track_num, jet_event.channel_num, jet_event.event_start)
                    config.set(segment_name, SEGMENT_END_MARKER, s)
                
            seg_num += 1
                        
        lib_num = 0
        config.add_section(LIBRARY_SECTION)
        for library in self.libraries:
            library_name = LIBRARY_FILENAME + str(lib_num)
            config.set(LIBRARY_SECTION, library_name, library)
            lib_num += 1
        
        FileKillClean(configFile)
        cfgfile = open(configFile,'w')
        config.write(cfgfile)
        cfgfile.close()
    
    def InitializeConfig(self, configFile):
        """ Initializes the values for an empty flag """
        self.config.filename = FileJustRoot(configFile)  + ".JET"
        self.config.chase_controllers = True
        self.config.delete_empty_tracks = False
        self.config.copyright = None
        self.config.app_data = None
        self.segments = []
        self.libraries = []
        self.config_file = configFile
        self.SaveJetConfig(configFile)
        
        

#---------------------------------------------------------------
# main
#---------------------------------------------------------------
if __name__ == '__main__':
    sys = __import__('sys')
    optparse = __import__('optparse')

    # parse command line options
    parser = optparse.OptionParser(version=VERSION)
    parser.set_defaults(log_level=logging.INFO, log_file=None)
    parser.add_option('-d', '--debug', action="store_const", const=logging.DEBUG, dest='log_level', help='Enable debug output')
    parser.add_option('-l', '--log_file', dest='log_file', help='Write debug output to log file')
    (options, args) = parser.parse_args()

    # get master logger
    logger = logging.getLogger('')
    logger.setLevel(options.log_level)

    # create console logger
    console_logger = logging.StreamHandler()
    console_logger.setFormatter(logging.Formatter('%(message)s'))
    logger.addHandler(console_logger)

    # create rotating file logger
    if options.log_file is not None:
        file_logger = logging.FileHandler(options.log_file, 'w')
        file_logger.setFormatter(logging.Formatter('%(message)s'))
        logger.addHandler(file_logger)

    # process files
    for arg in args:
        print arg
        jet_file = JetFile(arg, options)
        jet_file.WriteJetFileFromConfig(options)




"""
 File:  
 JetDefs.py
 
 Contents and purpose:
 Holds definitions used throughout JetCreator
 
 Copyright (c) 2008 Android Open Source Project
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
 
      http://www.apache.org/licenses/LICENSE-2.0
 
 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
"""

import wx

class JetDefs():
    def CreateHelpIniFile(self):
        """ Used to create the help data file for context sensitive help """
        self.CreateHelpIniForDialog("SEGDLG_CTRLS")
        self.CreateHelpIniForDialog("EVTDLG_CTRLS")
        self.CreateHelpIniForDialog("PREFERENCES_CTRLS")
        self.CreateHelpIniForDialog("JET_PROPERTIES_CTRLS")
        self.CreateHelpIniForDialog("REPLICATE_CTRLS")
        self.CreateHelpIniForDialog("MOVE_CTRLS")
        
    def CreateHelpIniForDialog(self, dlgName):
        """ Used to create the help data file for context sensitive help """
        print("\n" + dlgName)
        lst = getattr(self, dlgName)
        u = __import__('JetUtils')
        for ctrl in lst:
            fld = ctrl[0]
            if fld[0:2] != "fr":
                if u.IniGetValue(self.JETCREATOR_HLP, dlgName, fld) == "":
                    u.IniSetValue(self.JETCREATOR_HLP, dlgName, fld, "")
                    print(fld)

    DEFAULT_MUTE_SYNC = False
    
    TEMP_JET_DIR = "./Tmp/"
    TEMP_JET_CONFIG_FILE = "./Tmp/Temp.jtc"
    UNTITLED_FILE = "Untitled.jtc"
    JETCREATOR_INI = "JetCreator.ini"
    JETMIDIFILES_INI = "JetMidiFiles.ini"
    JETCREATOR_HLP = "JetCreatorhlp.dat"
        
    #Postevent message defines
    PST_UPD_LOCATION = 1
    PST_PLAY = 2
    PST_DONE = 3
    PST_PAUSE = 4
    PST_RESUME = 5
    PST_MIDI_INFO = 6
    
    #Dialog titles and prompts
    DLG_JETOPEN = "Open Jet File"
    DLG_PREFERENCES = "Preferences"
    DLG_ABOUT = "About"
    DLG_PROPERTIES = "Jet Project Properties"
    DLG_AUDITION = "Audition Jet File"
    DLG_REPLICATE = "Replicate Event"
    DLG_MOVE = "Move Events"
    MAIN_TITLEPREFIX = 'Jet Creator - '
    MAIN_DLG_CTRLS = 'JET_CREATOR'
    MAIN_SEGLIST = 'segList'
    MAIN_EVENTLIST = 'eventList'
    MAIN_ADDSEGTITLE = "Add Segments"
    MAIN_REVSEGTITLE = "Revise Segments"
    MAIN_ADDEVENTTITLE = "Add Event"
    MAIN_REVEVENTTITLE = "Revise Event"
    MAIN_CONFIRM = "Confirm Deletion"
    MAIN_CONFIRM_SEG_DLT = "\n\nOkay to delete segment(s)?"
    MAIN_CONRIRM_EVT_DLT = "\n\nOkay to delete event(s)?"
    MAIN_PLAYSEG = "Play Segments"
    MAIN_PLAYSEGMSG = "Queue one or more segments by checking them in the list, then play."
    MAIN_HELPTITLE = "Jet Creator Help"
    MAIN_HELPFILE = "JET Creator User Manual.htm"
    MAIN_HELPGUIDELINESTITLE = "Jet Authoring Guidelines"
    MAIN_HELPGUIDELINESFILE = "JET Authoring Guidelines.htm"
    MAIN_IMPORTTITLE = "Import Project"
    MAIN_IMPORTMSG = "Okay to import\n\n%s\n\ninto\n\n%s?"
    MAIN_SAVEBEFOREEXIT = "Save project before exiting?"
    MAIN_JETCREATOR = "Jet Creator"
    
    #Audition window defines
    AUDITION_CTRLS = 'AUDITION_CTRLS'
    AUDITION_SEGLIST = 'segList'
    AUDITION_QUEUELIST = 'queueList'
    AUDITION_TRACKLIST = 'trackList'
    AUDITION_GRAPH = 'graph'
    
    PLAY_TRIGGERCLIP_MSG = 'Triggered Clip %d: %s'
    
    #Config file defines
    RECENT_SECTION = "Recent"
    DIR_SECTION = "Directories"
    IMAGES_DIR = "ImagesDir"
    INI_PREF_SECTION = "Preferences"
    INI_PROJECT_DIRS = "chkProjectDir"
    INI_LOGGING = "Logging"
    INI_DEFAULTDIRS = "Directories"
    INI_DISPEMPTYTRACKS = "DisplayEmptyTracks"
    INI_EVENTSORT = "EventSort"
    INI_EVENTSORT_0 = "EventSort0"
    INI_EVENTSORT_1 = "EventSort1"
    INI_SEGSORT = "SegSort"
    INI_SEGSORT_0 = "SegSort0"
    INI_SEGSORT_1 = "SegSort1"
    
    #Mbt defines
    MBT_DEFAULT = (0,0,0)
    MBT_MIN = 0
    MBT_ZEROSTR = "0:0:0"
    
    #File open dialog specs
    APPLICATION_TITLE = "Jet Creator"
    MIDI_FILE_SPEC = 'MIDI Files (*.mid)|*.mid|All Files (*.*)|*.*'
    DLS_FILE_SPEC = 'DLS Files (*.dls)|*.dls|All Files (*.*)|*.*'
    JTC_FILE_SPEC = 'Jet Content Files (*.jtc)|*.jtc|All Files (*.*)|*.*'
    ARCHIVE_FILE_SPEC = 'Jet Archive Files (*.zip)|*.zip|All Files (*.*)|*.*'
    OPEN_PROMPT = "Open Jet Creator File"
    SAVE_PROMPT = "Save Jet Creator File"
    EXPORT_ARCHIVE_PROMPT = "Save Jet Archive"
    MUST_SAVE_FIRST = "You must save your JetCreator project before exporting it."
    IMPORT_ARCHIVE_PROMPT = "Select the Jet Archive to import"
    IMPORT_ARCHIVEDIR_PROMPT = "Choose a directory:\n\nYour imported project files will be placed there."
    IMPORT_ARCHIVE_NO_JTC = "This does not appear to be a JetCreator archive file."
    IMPORT_NOT_JET_ARCHIVE = "Not a recognized Jet Archive file."
    
    #Button texts
    BUT_ADD = 'Add'
    BUT_REVISE = 'Revise'
    BUT_DELETE = 'Delete'
    BUT_PLAY = 'Play'
    BUT_STOP = 'Stop'
    BUT_MOVE = 'Move'
    BUT_QUEUEALL = 'Queue All'
    BUT_DEQUEUEALL = 'Dequeue All'
    BUT_UNMUTE = 'Un-Mute'
    BUT_MUTE = 'Mute'
    BUT_AUDITION = 'Audition'
    BUT_QUEUE = 'Queue'
    BUT_MUTEALL = 'Mute All'
    BUT_MUTENONE = 'Mute None'
    BUT_ORGMUTES = 'Original Mutes'
    BUT_CANCELANDQUEUE = 'Cancel && Queue'
    BUT_CANCELCURRENT = 'Next'
    BUT_PAUSE = 'Pause'
    BUT_RESUME = 'Resume'
    BUT_PLAYSEG = 'Play Segment'
    BUT_PLAYMIDI = 'Play MIDI File'
    
    #Grid defines
    GRD_TRACK = "Track"
    GRD_CHANNEL = "Channel"
    GRD_NAME = "Name"
    GRD_SEGMENTS = "Segments"
    GRD_LENGTH = "Length"
    GRD_QUEUE = "Queue"
    GRD_STATUS = "Status"
    
    #Menu defines
    MNU_ADD_SEG = "Add Segment"
    MNU_UPDATE_SEG = "Revise Segment"
    MNU_DELETE_SEG = "Delete Segment"
    MNU_MOVE_SEG = "Move Segment(s)"
    MNU_ADD_EVENT = "Add Event"
    MNU_UPDATE_EVENT = "Revise Event"
    MNU_DELETE_EVENT = "Delete Event"
    MNU_MOVE_EVENT = "Move Events(s)"
    MNU_UNDO = "Undo\tctrl+z"
    MNU_REDO = "Redo\tctrl+y"
    
    HLP_QUANTIZE = "The quantize element is optional and defaults to 0 if omitted.\nThis value sets a window size in ticks for the breaks in\n a segment when notes are extracted from a larger file. \nSee the section on Quantization for further detail \non the operation of this parameter."
    
    #Status bar messages
    SB_NEW = "New JET Creator file"
    SB_OPEN = "Open JET Creator file"
    SB_SAVE = "Save Jet Creator file and generate .JET output file"
    SB_SAVEAS = "Save JET Creator file as another file"
    SB_EXIT = "Exit the application"
    SB_CUT = "Cuts the current segment or event to the clipboard"
    SB_COPY = "Copies the current segment or event to the clipboard"
    SB_PASTE = "Pastes the current segment or event from the clipboard"
    SB_UNDO = "Undo the last segment or event edit."
    SB_REDO = "Reverse the last segment or event undo edit."
    SB_IMPORT_PROJ = "Imports a JetCreator project archive."
    SB_EXPORT_PROJ = "Saves all project files to an archive."
    
    #Defines the menus
    MENU_SPEC = (("&File",
                    ("&New", SB_NEW, 'OnJetNew', True),
                    ("&Open...", SB_OPEN, 'OnJetOpen', True),
                    ("&Save", SB_SAVE, 'OnJetSave', True),
                    ("Save As...", SB_SAVEAS, 'OnJetSaveAs', True),
                    ("", "", "", True),
                    ("Import Project...", SB_IMPORT_PROJ, "OnJetImportArchive", True),
                    ("Export Project...", SB_EXPORT_PROJ, "OnJetExportArchive", True),
                    ("Properties...", "Sets properties specific to this Jet project", 'OnJetProperties', True),
                    ("", "", "", True),
                    ("Exit", SB_EXIT, 'OnClose', True)),
                ("&Edit",
                    (MNU_UNDO, "Undo", 'OnUndo', False),
                    (MNU_REDO, "Redo", 'OnRedo', False),
                    ("C&ut\tctrl+x", "Cut", 'OnCut', True),
                    ("&Copy\tctrl+c", "Copy", 'OnCopy', True),
                    ("&Paste\tctrl+v", "Paste", 'OnPaste', True)),
                ("Jet",
                    ("Preferences", "Set user preferences including defaults for new project files.", 'OnPreferences', True)),
                ("Segments",
                    (MNU_ADD_SEG, "Add a new segment to the segment list", 'OnSegmentAdd', True),
                    (MNU_UPDATE_SEG, "Revise the segment attributes", 'OnSegmentUpdate', False),
                    (MNU_DELETE_SEG, "Delete the segment from the segment list", 'OnSegmentDelete', False),
                    (MNU_MOVE_SEG, "Move one or more segments by incrementing or decrementing their time values", 'OnSegmentsMove', False)),
                ("Events",
                    (MNU_ADD_EVENT, "Add a new event for the currently selected segment", 'OnEventAdd', False),
                    (MNU_UPDATE_EVENT, "Revise the current event's attributes", 'OnEventUpdate', False),
                    (MNU_DELETE_EVENT, "Delete the event from the event list for this segment", 'OnEventDelete', False),
                    (MNU_MOVE_EVENT, "Move one or more events by incrementing or decrementing their time values", 'OnEventsMove', False)),
                ("Help",
                    ("JET Creator User Manual", "Get help on the JET Creator", "OnHelpJet", True),
                    ("JET Authoring Guidelines", "Guidelines helpful for JET content creation", "OnHelpJetGuidelines", True),
                    ("About", "About the JET Creator", "OnAbout", True))
                    )

    #Define the toolbar
    TOOLBAR_SPEC = (
                    ("-", "", "", ""),
                    ("New", "img_New", SB_NEW, "OnJetNew"),
                    ("Open", "img_Open", SB_OPEN, "OnJetOpen"),
                    ("Save", "img_Save", SB_SAVE, "OnJetSave"),
                    ("-", "", "", ""),
                    ("Cut", "img_Cut", SB_CUT, "OnCut"),
                    ("Copy", "img_Copy", SB_COPY, "OnCopy"),
                    ("Paste", "img_Paste", SB_PASTE, "OnPaste"),
                    ("-", "", "", ""),
                    ("Undo", "img_Undo", SB_UNDO, "OnUndo"),
                    ("Redo", "img_Redo", SB_REDO, "OnRedo"),
                    )
 
    F_HLPBUT = "hlpButton"
    F_OK = "btnOk"
    F_CANCEL = "btnCancel"
    F_MIDIFILE = "filecmbMidiFile"
    F_DLSFILE = "filecmbDlsFile"
    F_SEGNAME = "txtSegName"
    F_START = "tmStart"
    F_END = "tmEnd"
    F_QUANTIZE = "spnQuantize"
    F_REPEAT = "spnRepeat"
    F_TRANSPOSE = "spnTranspose"
    F_MUTEFLAGS = "grd2MuteFlags"
    F_SYNCMUTE = "chkSync"
    F_ETYPE = "cmbEventType"
    F_ENAME = "txtEventName"
    F_ESTART = "tmEventStart"
    F_EEND = "tmEventEnd"
    F_EID = "spnEventID"
    F_ETRACK = "spnEventTrack"
    F_ECHANNEL = "spn1EventChannel"
    F_EEVENTID = "spnEventID"
    F_EMUTEBUT = "btnMute"
    F_ETRIGGERBUT = "btnTriggerClip"
    F_GRAPH = "graphPlay"
    F_PAUSE = "btnPause"
    F_ADDSEG = "btnAddSeg"
    F_UPDSEG = "btnUpdateSeg"
    F_DELSEG = "btnDeleteSeg"
    F_PLAY = "btnPlay"
    F_PLAYMIDI = "btnPlayMidi"
    F_EASPLAY = "btnEasPlay"
    F_ADDCLIP = "btnAddEvent"
    F_UPDCLIP = "btnUpdateEvent"
    F_DELCLIP = "btnDeleteEvent"
    F_EXPORT = "btnOkExport"
    F_JETFILENAME = "filecmbJetFileName"
    F_COPYRIGHT = "txtCopyright"
    F_JFILE = "filetxtJetFileName"
    F_JOPEN = "btnOpen"
    F_JNEW = "btnNew"
    F_JIMPORT = "btnImport"
    F_JLIST = "lstRecent"
    F_ERRGRID = "grdErrors"
    F_CHASECONTROLLERS = "chkChaseControllers"
    F_DELETEEMPTYTRACKS = "chkDeleteEmptyTracks"
    F_OPTMIDI = "optMidiGraph"
    F_OPTSEG = "optSegGraph"
    F_RDOGRAPH = "rdoboxGraphType"
    F_DISPEMPTYTRACKS = "chkDisplayEmptyTracks"
    F_GRAPHLABELS = "chkGraphLabels"
    F_GRAPHCLIPS = "chkGraphClips"
    F_GRAPHAPPEVTS = "chkGraphAppEvts"
    F_REPLICATE = "btnReplicate"
        
    GRAPH_LBLS = "Labels"
    GRAPH_TRIGGER = "Trigger Clips"
    GRAPH_APP = "App Events"
    
    #IDs for dialogs
    ID_JET_OPEN = 0
    ID_JET_NEW = 1
    ID_JET_IMPORT = 2
        
    #Event types
    E_CLIP = 'TriggerClip'
    E_EOS = 'End of Segment'
    E_APP = 'App Controller'
       
    INTWIDTH = 70
    TIMEWIDTH = 70
   
    #Definitions of fields in the edit frame
    TM_WIDTH = 100
    TRACK_MIN = 1
    TRACK_MAX = 32
    EVENTID_MIN = 1
    EVENTID_MAX = 63
    APPCONTROLLERID_MIN = 80
    APPCONTROLLERID_MAX = 83
    #NEEDS TO DEFAULT TO RANGE OF BOTH POSSIBLE TYPES
    DEFAULTID_MIN = 1
    DEFAULTID_MAX = 100
    
    #Mins and maxs for dialog values
    QUANTIZE_MIN = 0
    QUANTIZE_MAX = 9
    CHANNEL_MIN = 1
    CHANNEL_MAX = 16
    TRANSPOSE_MIN = -12
    TRANSPOSE_MAX = 12
    REPEAT_MIN = -1
    REPEAT_MAX = 100
    
    #Standardize the columns
    BUTSIZE = wx.DefaultSize
    COLSIZE = 120
    COL1 = 30
    COL2 = COL1 + COLSIZE
    COL3 = COL2 + COLSIZE
    COL4 = COL3 + COLSIZE
    COL5 = COL4 + COLSIZE
    COL6 = COL5+ COLSIZE
    COL7 = COL6 + COLSIZE
    ROWSIZE = 50
    ROW1 = 40
    ROW2 = ROW1 + ROWSIZE
    ROW3 = ROW2 + ROWSIZE
    ROW4 = ROW3 + ROWSIZE
    ROW5 = ROW4 + ROWSIZE
    ROW6 = ROW5 + ROWSIZE
    ROW7 = ROW6 + ROWSIZE
    BUTOFF = 25
    BUTROW1 = 25
    FILEPATH_GRIDWIDTH = 120
    FILEPATH_WIDTH = 250
    
    #Segment grid column definitions
    SEGMENT_GRID = [('Segment Name', 200, F_SEGNAME),
                    ('MIDI File', FILEPATH_GRIDWIDTH, F_MIDIFILE),
                    ('DLS File', FILEPATH_GRIDWIDTH, F_DLSFILE),
                    ('Start', TIMEWIDTH, F_START),
                    ('End', TIMEWIDTH, F_END),
                    ('Quantize', 0, F_QUANTIZE),
                    ('Transpose', 0, F_TRANSPOSE),
                    ('Repeat', 0, F_REPEAT),
                    ('Mute Flags', 0, F_MUTEFLAGS)
                   ]
    
    #Clips grid column definitions
    CLIPS_GRID =   [('Event Name', 200, F_ENAME),
                    ('Type', 100, F_ETYPE),
                    ('Start',TIMEWIDTH, F_ESTART),
                    ('End',TIMEWIDTH, F_EEND),
                    ('Track',0, F_ETRACK),
                    ('Channel',0, F_ECHANNEL),
                    ('EventID',0, F_EEVENTID)
                   ]
    
    #Jet open dialog control definitions
    JETOPEN_SIZE = (365+200,360)
    JETOPEN_CTRLS = [
             ('Jet Creator Files', 'frCreator', 20, 20, (234+200, 244 + ROWSIZE), 0, 0, -1, [], "", True, ""),
             ('Open', F_JOPEN, BUTROW1, COL3+200, BUTSIZE, 0, 0, ID_JET_OPEN, [], "OnOk", True, ""),
             ('New', F_JNEW, BUTROW1+BUTOFF*1, COL3+200, BUTSIZE, 0, 0, ID_JET_NEW, [], "OnNew", True, ""),
             ('Import', F_JIMPORT, BUTROW1+BUTOFF*2, COL3+200, BUTSIZE, 0, 0, ID_JET_IMPORT, [], "OnJetImport", True, ""),
             ('Cancel', F_CANCEL, BUTROW1+BUTOFF*3, COL3+200, BUTSIZE, 0, 0, wx.ID_CANCEL, [], "", True, ""),
             ('', F_JFILE, ROW1, COL1, 200+200, 0, 0, -1, JTC_FILE_SPEC, "", True, ""),
             ('Recent Files', F_JLIST, ROW2, COL1, (200+200,200), 0, 0, -1, [], "", True, ""),
             ]

    #Jet properties dialog control definitions
    JET_PROPERTIES_SIZE = (465,460)
    JET_PROPERTIES_CTRLS = [
             ('Jet Project Properties', 'frProperties', 20, 20, (334, 344 + ROWSIZE), 0, 0, -1, [], "", True, ""),
             ('Ok', F_OK, BUTROW1, COL3+100, BUTSIZE, 0, 0, wx.ID_OK, [], "OnOk", True, ""),
             ('Cancel', F_CANCEL, BUTROW1+BUTOFF*1, COL3+100, BUTSIZE, 0, 0, wx.ID_CANCEL, [], "", True, ""),
             ('Jet File', F_JETFILENAME, ROW1, COL1, 300, 0, 0, -1, JTC_FILE_SPEC, "", True, ""),
             ('Copyright', F_COPYRIGHT, ROW2, COL1, 300, 0, 0, -1, [], "", True, ""),
             ('Chase Controllers', F_CHASECONTROLLERS, ROW3, COL1, 200, 0, 0, -1, [], "", True, ""),
             ('Delete Empty Tracks', F_DELETEEMPTYTRACKS, ROW4 - ROWSIZE/2, COL1, 200, 0, 0, -1, [], "", True, ""),
             ]
    
    #Preferences dialog control definitions
    PREFERENCES_SIZE = (465,460)
    PREFERENCES_CTRLS = [
             ('Preferences', 'frPreferences', 20, 20, (334, 344 + ROWSIZE), 0, 0, -1, [], "", True, ""),
             ('Ok', F_OK, BUTROW1, COL3+100, BUTSIZE, 0, 0, wx.ID_OK, [], "OnOk", True, ""),
             ('Cancel', F_CANCEL, BUTROW1+BUTOFF*1, COL3+100, BUTSIZE, 0, 0, wx.ID_CANCEL, [], "", True, ""),
             ('Copyright', F_COPYRIGHT, ROW1, COL1, 300, 0, 0, -1, [], "", True, ""),
             ('Chase Controllers', F_CHASECONTROLLERS, ROW2, COL1, 200, 0, 0, -1, [], "", True, ""),
             ('Delete Empty Tracks', F_DELETEEMPTYTRACKS, ROW3 - ROWSIZE/2, COL1, 200, 0, 0, -1, [], "", True, ""),
#             ('Use Project Directories', INI_PROJECT_DIRS, ROW1, COL1, 150, 0, 0, -1, [], "", True, ""),
             ]
    
    #Error dialog control definitions
    ERRORCOLW = 220
    ERRORDLG_SIZE = (600,400)
    ERRORDLG = [
             ('Ok', F_OK, BUTROW1, 500, BUTSIZE, 0, 0, wx.ID_OK, [], "OnOk", True, ""),
             ('', F_ERRGRID, BUTROW1, COL1, (200,300), 0, 0, -1, [], "", True, ""),
             ]
    
    #Event dialog control definitions
    BGR = 100
    EVT_OFFSET = 525+BGR
    EVTDLG_SIZE = (375+EVT_OFFSET,530)
    ID_MUTE = 124
    ID_MIDIFILE = 123
    ID_TRIGGERCLIP = 122
    SEGFRAME_SIZE = (500+BGR, 344 + ROWSIZE)
    TRACKGRD_SIZE = (70, SEGFRAME_SIZE[1]-50)
    GRAPH_SIZE = (760, 50)
    AUDCOL=190
    EVTDLG_CTRLS = [
             ('Segment', 'frSeg', 20, 20, SEGFRAME_SIZE, 0, 0, -1, [], "", False, ""),
             ('Segment Name', F_SEGNAME, ROW1, COL1, 200+BGR, 0, 0, -1, [], "", False, ""),
             ('MIDI File', F_MIDIFILE, ROW2, COL1, FILEPATH_WIDTH+BGR, 0, 0, ID_MIDIFILE, MIDI_FILE_SPEC, "", False, ""),
             ('DLS File', F_DLSFILE, ROW3, COL1, FILEPATH_WIDTH+BGR, 0, 0, -1, DLS_FILE_SPEC, "", False, ""),
             ('Starting M/B/T', F_START, ROW4, COL1, TM_WIDTH, 0, 0, -1, [], "", False, ""),
             ('Ending M/B/T', F_END, ROW5, COL1, TM_WIDTH, 0, 0, -1, [], "", False, ""),
             ('Quantize', F_QUANTIZE, ROW6, COL1, INTWIDTH, QUANTIZE_MIN, QUANTIZE_MAX, -1, [], "", False, HLP_QUANTIZE),
             ('Repeat', F_REPEAT, ROW4, AUDCOL, INTWIDTH, REPEAT_MIN, REPEAT_MAX, -1, [], "", False, ""),
             ('Transpose', F_TRANSPOSE, ROW5, AUDCOL, INTWIDTH, TRANSPOSE_MIN, TRANSPOSE_MAX, -1, [], "", False, ""),
             ('Event', 'frEventg', 20+EVT_OFFSET, 20, (234, 344 + ROWSIZE), 0, 0, -1, [], "", True, ""),
             ('Ok', F_ADDCLIP, BUTROW1, COL3+EVT_OFFSET, BUTSIZE, 0, 0, wx.ID_OK, [], "OnOk", True, ""),
             ('Cancel', F_CANCEL, BUTROW1+BUTOFF*1, COL3+EVT_OFFSET, BUTSIZE, 0, 0, wx.ID_CANCEL, [], "OnClose", True, ""),
             ('Replicate', F_REPLICATE, BUTROW1+BUTOFF*2, COL3+EVT_OFFSET, BUTSIZE, 0, 0, wx.ID_CANCEL, [], "OnReplicate", True, ""),
             ('Event Name', F_ENAME, ROW1, COL1+EVT_OFFSET, 200, 0, 0, -1, [], "", True, ""),
             ('Event Type', F_ETYPE, ROW2, COL1+EVT_OFFSET, 120, 0, 0, -1, [E_CLIP, E_EOS, E_APP], "OnEventSelect", True, ""),
             ('Starting M/B/T', F_ESTART, ROW3, COL1+EVT_OFFSET, TM_WIDTH, 0, 0, -1, [], "", True, ""),
             ('Ending M/B/T', F_EEND, ROW4, COL1+EVT_OFFSET, TM_WIDTH, 0, 0, -1, [], "", True, ""),
             ('Track', F_ETRACK, ROW5, COL1+EVT_OFFSET, INTWIDTH, TRACK_MIN, TRACK_MAX, -1, [], "", True, ""),
             ('Track Mutes', F_MUTEFLAGS, ROW1, COL3 + 15+BGR, TRACKGRD_SIZE, 0, 0, -1, [], "", False, ""),
             ('Channel', F_ECHANNEL, ROW6, COL1+EVT_OFFSET, INTWIDTH, CHANNEL_MIN, CHANNEL_MAX, -1, [], "", True, ""),
             ('EventID', F_EEVENTID, ROW7, COL1+EVT_OFFSET, INTWIDTH, DEFAULTID_MIN, DEFAULTID_MAX, -1, [], "", True, ""),
             ('Play', F_PLAY, BUTROW1+BUTOFF*4, COL3+EVT_OFFSET, BUTSIZE, 0, 0, -1, [], "OnPlay", True, ""),
             ('Trigger', F_ETRIGGERBUT, BUTROW1+BUTOFF*5, COL3+EVT_OFFSET, BUTSIZE, 0, 0, ID_TRIGGERCLIP, [], "OnTriggerClip", False, ""),
             ('Un-Mute', F_EMUTEBUT, BUTROW1+BUTOFF*6, COL3+EVT_OFFSET, BUTSIZE, 0, 0, ID_MUTE, [], "OnMute", False, ""),
             ('Pause', F_PAUSE, BUTROW1+BUTOFF*7, COL3+EVT_OFFSET, BUTSIZE, 0, 0, -1, [], "OnPause", False, ""),
             ('Graph', F_GRAPH, 430, 20, (EVTDLG_SIZE[0]-40,60), 0, 0, -1, [], "", True, ""),
             (GRAPH_LBLS, F_GRAPHLABELS, (BUTROW1+BUTOFF*10)+70, COL3+EVT_OFFSET+5, 200, 0, 0, -1, [], "OnSetGraphOptions", True, ""),
             (GRAPH_APP, F_GRAPHCLIPS, (BUTROW1+BUTOFF*10)+90, COL3+EVT_OFFSET+5, 200, 0, 0, -1, [], "OnSetGraphOptions", True, ""),
             (GRAPH_TRIGGER, F_GRAPHAPPEVTS, (BUTROW1+BUTOFF*10)+110, COL3+EVT_OFFSET+5, 200, 0, 0, -1, [], "OnSetGraphOptions", True, ""),
             ("Graph", "boxGraph", (BUTROW1+BUTOFF*10)+45, COL3+EVT_OFFSET, (90,95), 0, 0, -1, [], "", True, ""),

          ]
      
    #Segment dialog control definitions
    BGR = 100
    AUDCOL = 560
    COLADD = 500 + BGR
    SEGDLG_SIZE = (890+BGR,530)
    SEGFRAME_SIZE = (375+BGR, 394)
    AUDFRAME_SIZE = (350, 394)
    TRACKGRD_SIZE = (200, AUDFRAME_SIZE[1]-60)
    MUTEGRD_TRACK = 50
    MUTEGRD_CHANNEL = 60
    MUTEGRD_NAME = 100
    BIGBUT = (100, 25)
    FILEPATH_WIDTH = 350
    SEGDLG_CTRLS = [
             ('Segment', 'frSeg', 20, 20, SEGFRAME_SIZE, 0, 0, -1, [], "", True, ""),
             ('Audition', 'frAudition', SEGFRAME_SIZE[0]+30, 20, AUDFRAME_SIZE, 0, 0, -1, [], "", True, ""),
             ('Segment Name', F_SEGNAME, ROW1, COL1, 200+BGR, 0, 0, -1, [], "", True, ""),
             ('MIDI File', F_MIDIFILE, ROW2, COL1, FILEPATH_WIDTH+BGR, 0, 0, ID_MIDIFILE, MIDI_FILE_SPEC, "", True, ""),
             ('DLS File', F_DLSFILE, ROW3, COL1, FILEPATH_WIDTH+BGR, 0, 0, -1, DLS_FILE_SPEC, "", True, ""),
             ('Starting M/B/T', F_START, ROW4, COL1, TM_WIDTH, 0, 0, -1, [], "", True, ""),
             ('Ending M/B/T', F_END, ROW5, COL1, TM_WIDTH, 0, 0, -1, [], "", True, ""),
             ('Quantize', F_QUANTIZE, ROW6, COL1, INTWIDTH, QUANTIZE_MIN, QUANTIZE_MAX, -1, [], "", True, HLP_QUANTIZE),
             ('Repeat', F_REPEAT, ROW1, AUDCOL+100+BGR, INTWIDTH, REPEAT_MIN, REPEAT_MAX, -1, [], "", True, ""),
             ('Transpose', F_TRANSPOSE, ROW2, AUDCOL+100+BGR, INTWIDTH, TRANSPOSE_MIN, TRANSPOSE_MAX, -1, [], "", True, ""),
             ('Track Mutes', F_MUTEFLAGS, ROW1, COL3 + 145+BGR, TRACKGRD_SIZE, 0, 0, -1, [], "", True, ""),
             ('Display Empty Tracks', F_DISPEMPTYTRACKS, ROW1+TRACKGRD_SIZE[1]+20, COL3 + 145+BGR, 200, 0, 0, -1, [], "OnSetTrackDisplayOption", True, ""),
             ('Ok', F_ADDSEG, BUTROW1, COL3 + COLADD, BIGBUT, 0, 0, wx.ID_OK, [], "OnOk", True, ""),
             ('Cancel', F_CANCEL, BUTROW1+BUTOFF*1, COL3 + COLADD, BIGBUT, 0, 0, wx.ID_CANCEL, [], "OnClose", True, ""),
             ('Replicate', F_REPLICATE, BUTROW1+BUTOFF*2, COL3 + COLADD, BIGBUT, 0, 0, wx.ID_CANCEL, [], "OnReplicate", True, ""),

             ('Play Segment', F_PLAY, BUTROW1+BUTOFF*4, COL3 + COLADD, BIGBUT, 0, 0, -1, [], "OnPlay", True, ""),
             ('Play MIDI File', F_PLAYMIDI, BUTROW1+BUTOFF*5, COL3 + COLADD, BIGBUT, 0, 0, -1, [], "OnPlayMidi", True, ""),
             ('Pause', F_PAUSE, BUTROW1+BUTOFF*6, COL3 + COLADD, BIGBUT, 0, 0, -1, [], "OnPause", False, ""),
             ('Graph', F_GRAPH, 430, 20, (SEGDLG_SIZE[0]-40,60), 0, 0, -1, [], "", True, ""),
             ('Graph', F_RDOGRAPH, (BUTROW1+BUTOFF*10), COL3 + COLADD, (100,140), 0, 0, -1, ["MIDI File", "Segment"], "OnSetGraphType", True, ""),

             (GRAPH_LBLS, F_GRAPHLABELS, (BUTROW1+BUTOFF*10)+70, COL3 + COLADD+5, 200, 0, 0, -1, [], "OnSetGraphOptions", True, ""),
             (GRAPH_APP, F_GRAPHCLIPS, (BUTROW1+BUTOFF*10)+90, COL3 + COLADD+5, 200, 0, 0, -1, [], "OnSetGraphOptions", True, ""),
             (GRAPH_TRIGGER, F_GRAPHAPPEVTS, (BUTROW1+BUTOFF*10)+110, COL3 + COLADD+5, 200, 0, 0, -1, [], "OnSetGraphOptions", True, ""),
             ]        


    REPLICATE_MAX = 999
    F_RPINCREMENT = "tmIncrement"
    F_RPGRDPREVIEW = "grdPreview"
    F_RPPREFIX = "txtPrefix"
    F_RPREPLACE = "chkReplaceMatching"
    F_RPMOVE = "chkMoveMatching"
    F_RPNUMBER = "spnNumber"
    F_RPBUT = "btnPreview"
    REPLICATE_GRID =   [('Event Name', 200, F_ENAME),
                        ('Start',TIMEWIDTH, F_ESTART),
                        ('End',TIMEWIDTH, F_EEND)
                        ]
    REPLICATE_SIZE = (515,550)
    REPLICATEGRID_SIZE = (350,310)
    REPLICATE_CTRLS = [
             ('Replicate', 'frRep', 20, 20, (384, 480), 0, 0, -1, [], "", True, ""),
             ('Ok', F_OK, BUTROW1, COL3+150, BUTSIZE, 0, 0, wx.ID_OK, [], "OnOk", True, ""),
             ('Cancel', F_CANCEL, BUTROW1+BUTOFF*1, COL3+150, BUTSIZE, 0, 0, wx.ID_CANCEL, [], "", True, ""),
             ('Preview', F_RPBUT , BUTROW1+BUTOFF*2, COL3+150, BUTSIZE, 0, 0, -1, [], "OnPreview", True, ""),
             ('Name Prefix', F_RPPREFIX, ROW1, COL1, 300, 0, 0, -1, [], "", True, ""),
             ('Replace Existing Items Matching Prefix', F_RPREPLACE, ROW3, COL1, 200, 0, 0, -1, [], "", True, ""),
             ('Preview', F_RPGRDPREVIEW, ROW4-20, COL1, REPLICATEGRID_SIZE, 0, 0, -1, [], "", True, ""),
             ('Starting M/B/T', F_ESTART, ROW2, COL1, TM_WIDTH, 0, 0, -1, [], "", True, ""),
             ('Increment M/B/T', F_RPINCREMENT, ROW2, COL2+20, TM_WIDTH, 0, 0, -1, [], "", True, ""),
             ('Number', F_RPNUMBER, ROW2, COL3+40, INTWIDTH, 1, REPLICATE_MAX, -1, [], "", True, ""),
             ]
    
    
    MOVE_SIZE = (350,390)
    MOVE_CTRLS = [
             ('Move', 'frRep', 20, 20, (384, 480), 0, 0, -1, [], "", True, ""),
             ('Ok', F_OK, BUTROW1, COL3+150, BUTSIZE, 0, 0, wx.ID_OK, [], "OnOk", True, ""),
             ('Cancel', F_CANCEL, BUTROW1+BUTOFF*1, COL3+150, BUTSIZE, 0, 0, wx.ID_CANCEL, [], "", True, ""),
             ('Preview', F_RPBUT , BUTROW1+BUTOFF*2, COL3+150, BUTSIZE, 0, 0, -1, [], "OnPreview", True, ""),
             ('Starting M/B/T', F_ESTART, ROW1, COL1, TM_WIDTH, 0, 0, -1, [], "", True, ""),
             ('Increment M/B/T', F_RPINCREMENT, ROW1, COL2+20, TM_WIDTH, 0, 0, -1, [], "", True, ""),
             ('Preview', F_RPGRDPREVIEW, ROW2, COL1, MOVE_SIZE, 0, 0, -1, [], "", True, ""),
             ]
   
if __name__ == '__main__':
    jd = JetDefs()
    jd.CreateHelpIniFile()



#----------------------------------------------------------------------
# This file was generated by C:\Python25\Lib\site-packages\wx-2.8-msw-unicode\wx\tools\img2py.py
#
from wx import ImageFromStream, BitmapFromImage, EmptyIcon
import cStringIO, zlib


def getData():
    return zlib.decompress(
'x\xda\x01-\x08\xd2\xf7\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00 \x00\
\x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\
\x08d\x88\x00\x00\x07\xe4IDATX\x85\xad\x97{PU\xc7\x1d\xc7\xbf\xbb{\xce\xb9\
\x8fs/\xf7\x12^\x82T\xb8\x02Q\xab\xc18\nV\x1b\x9f\xa0M\x1f\x99\xb6\x7f\x946&\
\x13;M\x94\xe9\xa4\x99vb\x0c\x125\xe6\x86\xd2\x82\x8f\x90L\x9264\xd3vR\x9b4\
\xb1\xc9\xc4\xcc\xb4\xd3\xd6\x17\xad\xd1&\x05\xb5>\x88\x164 p\x91\xc7\xe5\
\xa1\xf7r\x9f\xe7\xecn\xff\xc0\xeb\xe0\x03\x84iw\xe67\xe7\xcc\xd9\xdf~\x7f\
\x9f\xf3\xdb\xfd\xed\xd9C0A{\xe9\xe5\xddU\xf1xl[$\x14wz\xbd\xde\x91\x89|om\
\xbb_\xaa\xad3M\xf3\'*\xb3\xda7m\xda\x14\x19\xcf\x8f\x8e\xd7Q[[\x9b\xc59\x7f\
:#=#\x96\xe4\xb2{\xa7\x12\xbc\xa6\xe6\xc5\xfb@HyZZzL\xc0\xdc4\x91\xef\xb8\
\x00\xaaF\xdfY\\\xbcX[S\xba\xd6"\t~X\xbd\xbbz\xf6d\x82K)\x89f\xb1\xee]\xfa\
\xa5/[\xd6\x96~\xc5\xc2(\xad\x98h\xec\x1d\x01jj\xaa\x96*\x9a\xb2\xb0 \xff^EJ\
\x82%\xc5K,6E{k2\x00;\xf7\xd4lp:\x93\xf2rsr\xa9\x10\x12\xc5\xc5\xc5v\x9b\xa2\
\xd5N\t\x00\x94\xce\xcf\xce\xfa\x02\xe3\x9cCJ\t\x8f\'\x8fZ\xad\xb6\xb9\xb5\
\xbb\x7f\xf6\xc8D\xc1\xab\xab\xab\xd3\x18%\xbbW\xaf*u\xc4\xe3\x06\xa4\x94\
\xc8\xcc\x9cN\xa5\x94ES\x02\xe0\xc0\xd9\xcf\xdb.1\t\t\x000\x0c\x13kJJuF\xd8\
\xab;^\xd9\x914\x9e\x98M\xd7^\x9d\xfb\xc5y\x9a\xa2\xa8\x90R\x82R\x8a\x93\xa7\
\x1a#\x9c\xf3O\xa6\x04\xb0\xf5\xd9\xad\xc7\xa5D\xdd\xf1\xe3\xc7\xc2\x94RH)a\
\xb5\xda\x91\x9f\x9foM\xe2\x8e\x9a;\x8d\xf9\xf9\xae\xaa\xe5\x84\x90\x87\xee\
\x9b7\xdf\xc29\x07\x00\x84BAttv\x85B\xc1\xe8\xfa)\x01\x00@(\x18y\xd1\xd7\xdd\
5\x12\x0c^\x03!\x04\x9c\x0b\x14-*\xb6\x11\x8a\xf5;wV\x17\x8e\xf5\xad\xaf\xaf\
W-\x8a\xe5w%\xabJ\xed\x86a\x02\x004M\xc5\xe1\x86\xc3!a\x98\x1b&*\xe1q\x01\
\xbc^o\xd80\x8d\x8d\x87\x8f\x1c\ni\xdahJ\xe3q\x03\x0f,]fe\x9a\xf6\x96\x94\
\x92$|\x83\xc1\xe1-\xe9\x19\xe9\xa9n\xf7=\x10B\x80\x10\x82\x8b\x17[\xcch,\
\xdaXQ\xb1u\xffx1&\x04\x00\x80\xcag\xb7}\x14\x8b\xc5\x9aZ/\xfe\xc7$\x84@J ++\
\x9b&9\x9c\xf9\xbbv\xd5\xac\x07\x80]\xbb\xaa<\xa0d\xcb\xf2\x07V\xeb\xf1x\x1c\
RJ0F\xd0t\xf2D\xdc\x88\xf2\x1fL\xa4\x7fW\x00\x00\x88\xc7\xf8\xe3M\'N\xc4\x15\
E\x81\x94\x12\xb1X\x0c%\xab\xd78\x08#\xaf\xd4\xd5\xedp3\xd5\xf6\x9b\xc5\xc5K\
4\xc3\x18]\xf5\x16\x8b\x05G\x8f\xfd=D\xa4\xac\xa9\xac\xac\xbc\xfc?\x03TVV\
\xb6I)^>v\xfch81\x15\x84P\xcc\x993W\xe3\xc2\xfe\x81\xc5b)\xca\xcd\xf1(\x89\
\xd4_\xbd6\x84\xbe>\xff\xa0\xd3\x99|\xc7\xc5:e\x00\x00\x18\tD\xaa|\xdd]\xc1\
\x91\x91 \x00\xc04M\xdc_x\xbf\x952\xba\xaahQ\xb1\x1e\x89D \xa5\x84\xddn\xc7\
\x91\x86\xc3!3\x1e\x7f\xac\xbc\xbc\xdc\xf8\xbf\x01x\xbd\xde\xa8\xc9\x8d\xc7\
\x0f7\x1c\n\xd9\xedvH)\x11\x89D\xb1jE\t9s\xf64\x84\x10P\x14\x05\xe7\x9a\xcf\
\xc4Mn\xfe\xa5\xa2b\xeb?&\xa3;i\x00\x00\xd8\xb2y\xdb\x9f\xe3F\xfc\xd3K\x9f\
\xb7\x9a\x8a\xa2\xe0\xe2\xa5\x16$\'\'C\xd34\\\xeeh\x07S\x18\xce5\x9f\x8b\t#\
\xf4\xe4d5\xa7\x04\x00\x00<\x1e\xdd\xd0\xd8\xd4\x18\xb7X,\xf0u\xfb\xd0\xdf\
\xdf\x8f\x15\xcbV\xa2\xa5\xf5\x02\x0e\x1e\xfak\x88ss\xcb\xe6\xcd\xde\xfe\xa9\
h\xb2\xa98\x1f<\xd8p\xf5\xeb32\x9f\x18\x94"yu\xc9\x83H\xec\x92$\x1cF\xef\xc7\
G\r\xc7\x81\x86\xb2?\xf5\xf4\x88\xa9h*Sq~\xc3\x86E\xeaG\xef{\x06=y8u\xb2\x11\
\xe6o\xeb\x119\xff\x19b\x83\x03\xb0\xc5c\xbat\xba\x9e\x07\xb0}*\x9a\xe4\xee.\
\xa3\xad\x1eP\x15\x079\xbf sf\x9e:#\x97\xb4gg\xa1\xf7\x83\xbd\xc8w\xa5!\xdb\
\x99\x02P\xe0\xe3\xce\x960\xe7r\xd6\xc6\x08|\x93\xd5\x1d7\x03o\x03\xc9\x92\
\xd2\'UB\xd6q)\xb3A\xa0Q\x83)\x16\xc2\x88>0\x00\xe3\\S\x04 \x1fv\x04\x87\xbe\
\x95\xa2\xeav\xcdb\x81\xc7\x9d\xaeu\x0e\x0f\x9c~\x97A\x95\x00e\x94v\x19\x9c\
\xbf\xab\n\xf1Z\x1904\xe9\x0c\xbc\r|\x87P\xfa\xebT\x97K\xc9\xce\xc8\xb0\xb9t\
\x1d\x12@\xdf\xd0\x10\xda|>X\xdc\xb6\xa8?6r\xc4\x19\x10\xdf\x0e:\xc9{\x19\
\xba\xeb\xab\xd3T\xa7\xc5a\xb7\xa3y\xa8\x1bk\xe7\x15\x81\x00\x18\x0e\x04\xd0\
\xe6\xf3E\xae\x0c\x0c\x98\xe0\xfc\x89u\xc0\xbe\xbb\x02\xfc\x81\xd2g(c/\x14\
\xe6\xe5\xe9\x86i\xa2\xa3\xb7\xf7Z0\x1c\xd6\x18c\xea\xc29s\x94p$\x82\xcf:\
\xda\xfbX\xdc\x9c^\x06\xf0\xd7\xd2\xe0\xb0G\xe9\xd1\x99\xee\xf4\xf9\x0e\xa8\
\x94ZU\xb4uv\x07\xb8\x10$\xc5\xe9$3\xb3\xb3\x1d\x94R4]\xb8\x1029\xafz\xd84o:\
\x1d\xddT\x86\xef\x00e\x84R\xef\xc2\xd9\xb3\xf5\xce\xde\xdeps[[\xd7\xf0\xc8\
\xc8\xf7\x15!R\xa2\xdcx\xee|[\x1b2RR L\x91T\x06p\x00\xf8\x91\x1f#AU\xac\xbc<\
\xd4\x0fS%h\xef\xba\x12\x88\xc5b\x0fs\xc3\x98\xdd;4\xb4\xe5_\xcd\xcd\xc3\x1d\
==\xd1\xa5\x85\x85\xbaB\xe9\xf6\xdfS\xfa\xdd;\x02\xec\x03\\\x84\xd27\xe7\x17\
\x14\xd8\xdb\xbb\xbb\xc3\x83\x81@\xa3[\x88\x82\xc7\x80\xfde@D\x13\xf8c8\x16\
\x8b(\x8a\x02Hy\xd3\xda\xf9\xf1\x10\x02jDr]\xd7\x117\x0c\x85\x00\'\xd7\x01W\
\x1e\x05^gBx\xae\xf8\xfd\xad\x97:;cEs\xe7\xea\n!\xbf\xda\x07\xdcs\x1b\x80Iiy\
\xaa\xdb\xad\x00\xc0\xc0\xd5\xab#n!\x1e\xfc\x1a\x10K\xf4s`Y\xb2\xae\x1b\xc1P\
\x08\nc\xed\xb7N\x9dBY\xbb\xce,p\xdal\xa6\x00V&\x9e\x97\x01\xd7\x98\x10\xcb\
\xbb\xfd\xfe(\x01\x90\x95\x96\xa6\x1a\x94n\xbc\r\x80\x12\xb2>;=\xdd\xee\xeb\
\xef\x0f\x9bB\xfctl\xf0z\xc0\xce\x18\xdbyonnRgOO\x94\x0b\xb1\xf7V\x00.\xc4\
\xde\xae\x9e\x9e\xa8\'++\x89R\xba\xa7\x1e\xb0\x8f\x85\x90\xc0\xce\x8e\x9e\
\x9e\xa8\';\xdb\xa62v\xe3\x88F\xc7\x08x\x1c\xba\x8eP8\x1c\'\xc0\xa9\xb1\xc1\
\x93\x18;\x90\x99\x9a\xea\xd24\r>\xbf\xdf0\x84\xf8\xe5m\x19\x10\xe2\x17\xdd~\
\xbf\xa1i\x1aR\\\xae\x14\'\xa5\x07\xc7Bp!\x9a\x82\xa1P\xd4\xe5t\xc2\xe4<\xf7\
6\x00B\x88\t\x00\xba\xcd\xc6\x08P\xf8\x14\x90\xf4&\xb0\xce\xc1X[fj\xea\x82y\
\x05\x05\xb6O\xce\x9c\t\rJ\xf9\xf4z@\x02H\x01\x90\x9a\xb02\x80\x0c\x00\x9bN\
\xb7\xb6\x86f\xe5\xe4XS\xdd\xee\x05\x0eJ\xdb\xeb\x81u\x8f\x00I\x84\xd2\x85\
\x0e]W)\xa5\x00pc\xbb\xbeQ\x86\xef)\xca\x87\x0599\xdfLq\xb9Hcss\xc8\xe4\x9c%\
\xe9\xba1\xdb\xe3qZ5\r\xff<{6\xdck\x9a\xf5Oq\xfe\xc6up\x8a\x9b\xcbX\x02\x10u\
\x8cm\x9c\xceX\xf9\xc2Y\xb3\xecQ\xc3@\x9b\xcf\x17\x0c\x84\xc3\x9a\xaa(\xa2d\
\xf1b\xdbp  O\x9c?\xff\xb7\xef\x19\xc67\x00\xf0\x84\x80R\x03\x14\xe40\xf6\
\xe9\xac\xdc\\\xc7\x8ci\xd3\xa8\xaa(\x08\x8c\x8c\xa0\xbd\xbb;\xea\xf3\xfb\
\xf9\x05)_\xa8\x12\xe2\x00\x00\x15\xa3;h\xc2\x18FK\xd2L\xd8s\x94\x96\xce\x03\
\xb6g\xa5\xa51\xcf\xf4\xe9\xd6\x14\xb7\x1b\x00\xe0\xeb\xeb\x13\xffni\t^4\xcd\
\x15\xcf\x03-\x00\x8c\xb1o@\xeb\x80\xc2tE\xd9CF\xffd(\x08\xe9\x1d\xe6|\xff\
\xfbR\xeem\x00\x82\xd7\x83%\x8c\x8c19\xc68\x00\xbe\x0cp\x96\x11\xf2h\x8a\xa2\
<D\x84\xc8\x04 $\xa5\xa7\xba\x0c\xe3\x99\n\xe0\xccuX9\xde\xc7(!Lo\tJ\xef`\
\x899\x95c\xae\xfc\xfa}"3bL\xdfM\xed\xbfj\xaa\x81\xd8\x9f\'F\x8c\x00\x00\x00\
\x00IEND\xaeB`\x82\x989\xee\xcb' )

def getBitmap():
    return BitmapFromImage(getImage())

def getImage():
    stream = cStringIO.StringIO(getData())
    return ImageFromStream(stream)

def getIcon():
    icon = EmptyIcon()
    icon.CopyFromBitmap(getBitmap())
    return icon




#----------------------------------------------------------------------
# This file was generated by C:\Python25\Lib\site-packages\wx-2.8-msw-unicode\wx\tools\img2py.py
#
from wx import ImageFromStream, BitmapFromImage, EmptyIcon
import cStringIO, zlib


def getData():
    return zlib.decompress(
'x\xda\x01\xf1\x03\x0e\xfc\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00 \
\x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x04sBIT\x08\x08\x08\x08\
|\x08d\x88\x00\x00\x03\xa8IDATX\x85\xc5\x97\xcdN\x1bW\x14\xc7\x7f\xe7\xce\
\xf5\x076\xb8@0\t\r\xd9T\x95\xca&\x8bnP\xd9t\xd5M\xb7}\x016\xac\xfa\x10\xddv\
\xd9\x15\xddU\xea\x0b\xf4\r*e\xd1E%\xd4\xd0(HMhD]\xd2\x00\x01SC\x80\xf8s\xee\
=]\x8cM\x8d=\xe31\x94*G\x1a\xcd\\\x8d\xe7\x9e\xdf\xf9\x9fs\xee\xf5\x85wl\xf2\
\x7fL\xaaJ\x8e\xd3\xdc\x02\x19?\x8b\x0f&\x000\xaeA\xc7\xd4\x98n\xed\x8b\xd0N\
\x04X__\xff\xc2Z\xfb\xbd1f\xca\x18\x831\x06\xef=\xde{\xc20\xc49\x17{\xef=O\
\xe4\xdf0\xf3\xde\t\x93\xc53\n\x13\r\xac\xedt\xbf5\xad{\xf3\xc7\xdf~\xfa\xc9\
\xce\x0f\xd0\xfc]JT\x01\xec \x801\xe6\xbb\xb5\xb5\xb5)\x91\x88-\x0cC\xac\xb5\
\xdd\xc8t R\xbd\xfa\xac\xaf\x11\xfd\r\xd1\x1d\xd0W\xa0U\x84F\xf4N\x8a\xb9G\
\x8f\xea_"\xd9\nhA\xb5\xf5X\x84\xda\x10\x80snZD\xa8T*\x88\x08\xce9\x8a\xc5"\
\xedv\x9b\x1e\xd4\xe0=zn\x93\r\xb6\xc8\xdam\xac\xd9!c\xf7\t\xa4\x8aJ7\x03\
\xd2f\xf1~=\x07\xb9\x87\x00\x9cK]\xb5\xf9\xf3\x10@/*\x11\xb9\xbc\xfa\xc7I\
\x00\x81\x1ca\x83Clp@&\xd8\'0\x17H\xf0\x11\xc8\x9d\xee/j\xcc\x97\xb7@\xb2K\
\xe0/\xc0U\xb9(\xbe\x18\x02\xf0\xde\xc7:\x1c\x05\x02`\xed\x19\x81y\x83\x91\
\x1a\x81T\x91`\td\t1\x8b\xd1o\xd9#\xc8\x9c\x83\x1e?@\xec+\x08\xca\xd0\xb8;\
\x12`\\%z\x12\x8b41\xd2\x04\x99\x00\x99E\xcc\x03\x08>\xeeN,\x88\xf9\x03\xa4\
\x94A\xff.!R\xc0\x05S\xb1\x00qi\x88\x93\xbf\x1f )5Q\xa3]-\xde\x7fe\x93N\\\
\x11\x8et\x9eX\x07\x92G5\x8f\x92G}\x1d1\xb5\xa8\x13\\o\xe6=\xd4\x1f\x83\x9e\
\x85\x88;G\xb5N\xe0c\xbb`\x08 i|5\xdaY\x94\x19\x949<5\x02\xff2\x8a[\x0e\xbb\
\xefOp\x9d?\xa1\xe0^\x82;\x00W\xe5\xb4\xf5\xda\x8c\x02\xd8\xdc\xdc\x8c\x05\
\x88\xbb<wQ\xde\xc7\xeb}\x9c_\xc4\xf9"\xb8mpO\xba\xd76\x87GM\xd0\xf66\xda\
\xa9 \xfa\\\x16x\x9b\xa8\x00\xc0\xf2\xf2\xf2e\xff\xa7\xa7"\x8f\xe7\x03\x9c6\
\xa2\x8f\xb5\x882\x07>\x1a\xdbL\x89\xca\xeec\x96>l=E\xdbO\x99lnA\xccJ\xe8\
\x9cCU\xa3\xa8\xae\xd9\x92J\x19\xa7\x0f\x81\x02\xeag0r\nD\x00\x81L\xf3b\xe7\
\x19\x9f\x7f\x16\xfe\xc4dsK$\xaa\x8e\x91\n\x0c\xda85\x01s8fPN\xf0\x1c!z\x01\
\x92\xc5\x9b\x05~\xf9\xf5Gd\xb2\xfe\xa4\x7f\xce\xb1\xbb \xcd\xf9\xd5\xd6\xb3\
(eT\xcb\xd1PA)Po\x0c\x95\xdcx\x00\xfd\x11\xa6\xb5g\x92\xa9\xeaeJS\x01\x06w\
\xbd\x9e]wm\x18\xb5{&\x02\x84a\x18\xeb4\r(\x0e`\xd0\xc6V \xceq\xda:pS\x80\
\xc4\x85\x08`cc\x03c\x86\x0bg\\@cLjm\x0c\xcd\x1e\x86\xe1e\xaeVVVFnLI\x8e\x93\
\x14\x8a\xb3\x91)\x18\xdc\x9aG)\x11\xbf&\xa4\xdb\xc8\x14\x8c\xe34\xed]\x1aLl\
\x17$\xb5\xe1M\xc0z\xcbz\x92\xddH\x81\xdb\xb4k\xed\x05iv\x13\xe5n\x04\xd0\
\xdf\x19i \xaa:\x12l\x10\xa0$"g\xaaZ*\x95J\x88D\xe7\x02k\xed\x7f\xae\x0b\x80\
l6{\x0e\xdc\x03N\x80\xd6 \xc0\x14P\xde\xdb\xdb\xfbzuu\xf5+\x91\xee\x89\xe2\
\x96LU\x9b\xbb\xbb\xbb\xdf\x00\x0b@\x00\x1c\x00\xbe_\xc3\x1c0\x0f\xdc\x01\
\xa6\xbb\xe3\xe0\x96\xfc7\x89\x82}\x0b\xd4\x80\xbf\x80\x0b\x88?\x1d\xe7\x80|\
\xf7~[\xa7g\x07t\x88do\xd1\xf7?\xfd\x1fi[\xcc\xd5\x90zP\xe4\x00\x00\x00\x00I\
END\xaeB`\x82\xd34\xc5\xd2' )

def getBitmap():
    return BitmapFromImage(getImage())

def getImage():
    stream = cStringIO.StringIO(getData())
    return ImageFromStream(stream)

def getIcon():
    icon = EmptyIcon()
    icon.CopyFromBitmap(getBitmap())
    return icon

